@@ -9,6 +9,8 @@
 
 #include "camera.h"	// config.h is here -> we get ENABLE-macros here...
 
+#include "main.h"
+
 #include "project.h"
 #include "views.h"
 
@@ -17,7 +19,7 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -29,10 +31,12 @@ camera::camera(const object_location & p1, fGL p2, project * p3) : dummy_object(
 	my_c_number = prj->GetNewCameraID();
 	graphics_view_counter = 1;
 	
-	my_object_name = new char[64];
-	ostrstream ons(my_object_name, 64);
+	ostringstream ons;
 	ons << "camera #" << my_c_number << ends;
 	
+	my_object_name = new char[64];
+	strcpy(my_object_name, ons.str().c_str());
+	
 	focus = p2;
 	clipping = 0.90;
 	
@@ -538,14 +542,20 @@ spot_light::spot_light(const object_location & p1, i32s myid, const light_compon
 	GetLocDataRW()->crd[3] = 1.0;		// make this a spotlight!!!
 	cutoff = p3; exponent = p4;
 	
-	my_object_name = new char[64];
-	ostrstream ons(my_object_name, 64);
+	ostringstream ons;
 	ons << "light (spotlight, object #" << myid << ")" << ends;
+	
+	my_object_name = new char[64];
+	strcpy(my_object_name, ons.str().c_str());
+	
+	my_glname = gtk_app::GetPrj()->RegisterGLName((dummy_object *) this);
 }
 
 spot_light::~spot_light(void)
 {
 	delete[] my_object_name;
+	
+	// todo : unregister my_glname!!!
 }
 
 void spot_light::SetupProperties(void)
@@ -575,8 +585,8 @@ void spot_light::Render(void)
 	fGL r2 = (1.0 - tmp1) * tmp2;
 	fGL r3 = tmp1 * tmp2;
 	
-	const dummy_object * name = this;
-	glPushName(GLNAME_LIGHT); glPushName((iGLu) name);
+	glPushName(GLNAME_LIGHT);
+	glPushName(my_glname);
 	
 	glPushMatrix(); SetModelView();
 	
@@ -621,9 +631,11 @@ void spot_light::Render(void)
 
 directional_light::directional_light(const object_location & p1, i32s myid, const light_components & p2) : light(p1, p2)
 {
-	my_object_name = new char[64];
-	ostrstream ons(my_object_name, 64);
+	ostringstream ons;
 	ons << "light (directional, object #" << myid << ")" << ends;
+	
+	my_object_name = new char[64];
+	strcpy(my_object_name, ons.str().c_str());
 }
 
 directional_light::~directional_light(void)
