@@ -18,7 +18,7 @@
 #include <ghemical/eng2_qm_mm.h>
 
 #include <iomanip>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 //#define VERBOSE	// un-comment this to enable debug-messages...
@@ -30,7 +30,9 @@ static char * my_num_locale = NULL;	// the temporary locale strings returned by
 bool ReadGPR_OLD(project & prj, istream & file, bool, bool)
 {
 	static const char message[] = "Hmmm. It seems that we are trying to read a VERY OLD version of this file.\nIt's not possible to verify the type and version of the file, so this\noperation may fail. Are you sure you wish to try (Y/N) ??? ";
-	bool result = prj.Question(message); if (!result) return false;
+	
+	bool result = prj.Question(message);
+	if (!result) return false;
 	
 	vector<atom *> tmp1; i32s tmp2[2]; char tmp3; fGL tmp4[3];
 	
@@ -157,7 +159,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : bad atom id numbers!!!" << endl;
 				element tmp_element(n2);
 				atom newatom(tmp_element, NULL, prj.GetCRDSetCount());
 				
-				if (selected) newatom.flags |= ATOMFLAG_SELECTED;
+				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
 				prj.AddAtom(newatom);
 
@@ -301,8 +303,7 @@ bool ReadGPR_v110(project & prj, istream & file, bool selected, bool skipheader)
 cout << "model::ReadStream() : starting file input." << endl;
 #endif	// VERBOSE
 	
-	delete prj.current_setup;			// get rid of the old setup...
-	prj.current_setup = new setup1_mm(& prj);	// ...and make a new temporary one.
+	prj.ReplaceCurrentSetup(new setup1_mm(& prj));
 	
 	char su_cn[16] = "unknown";	// the setup class classname.
 	i32s engid = NOT_DEFINED;	// the engine class ID.
@@ -362,7 +363,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : atom id number mismatch!!!" << en
 				atom newatom(tmp_element, NULL, prj.GetCRDSetCount());
 				
 				newatom.flags = n3;
-				if (selected) newatom.flags |= ATOMFLAG_SELECTED;
+				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
 				prj.AddAtom(newatom);
 
@@ -460,21 +461,22 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	// change the current_setup and current_eng using the settings from file.
 	// try to find a new setup class; if no success use the setup1_mm as a default.
 	
-	delete prj.current_setup;	// get rid of the temporary setup...
-	prj.current_setup = NULL;	// ...and mark it invalid.
+	setup * newsu = NULL;
 	
-	if (!prj.current_setup && !strcmp(setup1_qm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_qm(& prj);
-	if (!prj.current_setup && !strcmp(setup1_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_mm(& prj);
-	if (!prj.current_setup && !strcmp(setup1_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup1_sf(& prj, false);
+	if (!newsu && !strcmp(setup1_qm::static_GetClassName(), su_cn)) newsu = new setup1_qm(& prj);
+	if (!newsu && !strcmp(setup1_mm::static_GetClassName(), su_cn)) newsu = new setup1_mm(& prj);
+	if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
 	
-	if (!prj.current_setup && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup2_qm_mm(& prj);
+	if (!newsu && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) newsu = new setup2_qm_mm(& prj);
 	
-	if (!prj.current_setup)
+	if (!newsu)
 	{
 		prj.WarningMessage("did not find a matching setup");
-		prj.current_setup = new setup1_mm(& prj);
+		newsu = new setup1_mm(& prj);
 	}
 	
+	prj.ReplaceCurrentSetup(newsu);
+	
 	// now try to set a correct value for current_eng_index
 	
 	i32u index = 0;
@@ -492,7 +494,7 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 		index = 0;
 	}
 	
-	prj.GetCurrentSetup()->SetCurrentEngIndex(index);
+	prj.GetCurrentSetup()->SetCurrEngIndex(index);
 	
 	// ok, we are ready now!
 	
@@ -570,6 +572,7 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 		else if (version > current_version_number)
 		{
 			static const char message[] = "Ooops. It seems that we are trying to read a FUTURE version of this file.\nIt's not sure if we can handle that. Are you sure you wish to try (Y/N) ??? ";
+			
 			bool result = prj.Question(message);
 			if (!result)
 			{
@@ -590,8 +593,7 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 cout << "model::ReadStream() : starting file input." << endl;
 #endif	// VERBOSE
 	
-	delete prj.current_setup;			// get rid of the old setup...
-	prj.current_setup = new setup1_mm(& prj);	// ...and make a new temporary one.
+	prj.ReplaceCurrentSetup(new setup1_mm(& prj));
 	
 	char su_cn[16] = "unknown";	// the setup class classname.
 	i32s engid = NOT_DEFINED;	// the engine class ID.
@@ -653,7 +655,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : atom id number mismatch!!!" << en
 				newatom.formal_charge = n3;
 				
 				newatom.flags = n4;
-				if (selected) newatom.flags |= ATOMFLAG_SELECTED;
+				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
 				prj.AddAtom(newatom);
 
@@ -751,21 +753,22 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	// change the current_setup and current_eng using the settings from file.
 	// try to find a new setup class; if no success use the setup1_mm as a default.
 	
-	delete prj.current_setup;	// get rid of the temporary setup...
-	prj.current_setup = NULL;	// ...and mark it invalid.
+	setup * newsu = NULL;
 	
-	if (!prj.current_setup && !strcmp(setup1_qm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_qm(& prj);
-	if (!prj.current_setup && !strcmp(setup1_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_mm(& prj);
-	if (!prj.current_setup && !strcmp(setup1_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup1_sf(& prj, false)
-	;
-	if (!prj.current_setup && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup2_qm_mm(& prj);
+	if (!newsu && !strcmp(setup1_qm::static_GetClassName(), su_cn)) newsu = new setup1_qm(& prj);
+	if (!newsu && !strcmp(setup1_mm::static_GetClassName(), su_cn)) newsu = new setup1_mm(& prj);
+	if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
 	
-	if (!prj.current_setup)
+	if (!newsu && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) newsu = new setup2_qm_mm(& prj);
+	
+	if (!newsu)
 	{
 		prj.WarningMessage("did not find a matching setup");
-		prj.current_setup = new setup1_mm(& prj);
+		newsu = new setup1_mm(& prj);
 	}
 	
+	prj.ReplaceCurrentSetup(newsu);
+	
 	// now try to set a correct value for current_eng_index
 	
 	i32u index = 0;
@@ -783,7 +786,7 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 		index = 0;
 	}
 	
-	prj.GetCurrentSetup()->SetCurrentEngIndex(index);
+	prj.GetCurrentSetup()->SetCurrEngIndex(index);
 	
 	// change the original locale back...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -916,11 +919,6 @@ void WriteGPR_v100(project & prj, ostream & file)
 
 void WriteGPR(project & prj, ostream & file)
 {
-prj.Message("\
-PLEASE NOTE : This file format is EXPERIMENTAL!\n\n\
-This file format is NOT compatible with OpenBabel-1.100.2.\n\
-Please use the File/Export to generate OpenBabel-compatible files.");
-////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	if (my_num_locale != NULL) cout << "WARNING : my_num_locale != NULL" << endl;	// todo : change into a thread-safe lock???
 	// store the current (numeric) locale into my_num_locale, and switch into "C" numeric locale...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
