@@ -10,8 +10,8 @@
 #ifndef FILETRANS_H
 #define FILETRANS_H
 
-//#include "ghemicalconfig2.h"
 #include <ghemical/libghemicalconfig2.h>	// ENABLE_OPENBABEL
+#include "ghemicalconfig2.h"
 
 #ifdef ENABLE_OPENBABEL
 
@@ -23,10 +23,8 @@
 // OpenBabel includes...
 // OpenBabel includes...
 
-#include "mol.h"
-//#include "oeutil.h"
-//#include "data.h"
-//#include "typer.h"
+#include <openbabel/mol.h>
+#include <openbabel/obconversion.h>
 using namespace OpenBabel;
 
 #include <string>
@@ -43,8 +41,8 @@ typedef struct {
 } atom_name_tag;
 
 typedef struct {
-  string   format;
-  unsigned int offset;
+  string   description;
+  OBFormat * format;
 } format_record;
 
 class file_trans
