@@ -12,22 +12,21 @@
 #include "project.h"
 
 #include <iostream>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
 
 glade_dialog::glade_dialog(const char * xmlfile)
 {
-	char filename[256];
-	ostrstream str(filename, sizeof(filename));
+	ostringstream str;
 	str << project::appdata_path << DIR_SEPARATOR << project::appversion << DIR_SEPARATOR << xmlfile << ends;
 	
-	xml = glade_xml_new(filename, NULL, NULL);
+	xml = glade_xml_new(str.str().c_str(), NULL, NULL);
 	
 	if (xml == NULL)
 	{
-		cout << "ERROR : could not read glade XML file : " << filename << endl;
+		cout << "ERROR : could not read glade XML file : " << str.str() << endl;
 		exit(EXIT_FAILURE);
 	}
 }
