@@ -37,12 +37,27 @@ GtkActionEntry gtk_graphics_view::entries[] =
 	{ "ImportPDB", NULL, "_Import PDB", NULL, "Import a PDB file", (GCallback) gtk_project::popup_FileExtra1 },
 	{ "ConvertAA2SF", NULL, "_Convert AA2SF", NULL, NULL, (GCallback) gtk_project::popup_FileExtra2 },
 	
+#ifdef ENABLE_GAMESS
+	{ "GamessMenu", NULL, "_Gamess" },
+	// ^^^^^^^^^^^^^
+	{ "GamessInp", NULL, "_Gamess Input Deck", NULL, "Generate Gamess Input Deck...", (GCallback) gtk_project::popup_GamessInp },
+#ifdef ENABLE_OPENBABEL
+	{ "MarkQM", NULL, "_QM Selection", NULL, "Mark Molecule", (GCallback) gtk_project::popup_MarkQM },
+	{ "MarkEFP", NULL, "_EFP Selection", NULL, "Mark EFP", (GCallback) gtk_project::popup_MarkEFP },
+#endif  // ENABLE_OPENBABEL
+#endif  // ENABLE_GAMESS
+
+	
 	{ "SelectMenu", NULL, "_Select" },
 	// ^^^^^^^^^^
 	{ "SelectAll", NULL, "Select _All", NULL, "Select all atoms", (GCallback) gtk_project::popup_SelectAll },
 	{ "SelectNone", NULL, "Select _None", NULL, "Select nothing", (GCallback) gtk_project::popup_SelectNone },
 	{ "InvertSelection", NULL, "_Invert Selection", NULL, "Invert the selection", (GCallback) gtk_project::popup_InvertSelection },
-	{ "DeleteSelected", NULL, "_Delete Selected", NULL, "Delete all selected atoms", (GCallback) gtk_project::popup_DeleteSelection },
+	{ "HideSelected", NULL, "_Hide Selected", NULL, "Hide all selected atoms", (GCallback) gtk_project::popup_HideSelected },
+	{ "ShowSelected", NULL, "_Show Selected", NULL, "Show all selected atoms", (GCallback) gtk_project::popup_ShowSelected },
+	{ "LockSelected", NULL, "_Lock Selected", NULL, "Lock all selected atoms", (GCallback) gtk_project::popup_LockSelected },
+	{ "UnlockSelected", NULL, "_Unlock Selected", NULL, "Unlock all selected atoms", (GCallback) gtk_project::popup_UnlockSelected },
+	{ "DeleteSelected", NULL, "_Delete Selected", NULL, "Delete all selected atoms", (GCallback) gtk_project::popup_DeleteSelected },
 	
 	{ "SelectModeMenu", NULL, "_Selection Mode" },
 	// ^^^^^^^^^^^^^^
@@ -169,6 +184,11 @@ GtkActionEntry gtk_graphics_view::entries[] =
 	// ^^^^^^^^^^^^^^^^^^
 	{ "BuildHydrogensAdd", NULL, "Add", NULL, "...todo...", (GCallback) gtk_project::popup_HAdd },
 	{ "BuildHydrogensRemove", NULL, "Remove", NULL, "...todo...", (GCallback) gtk_project::popup_HRemove },
+#ifdef ENABLE_OPENBABEL
+	{ "BuildHydrogensHtoMethyl", NULL, "H->Methyl", NULL, "...todo...", (GCallback) gtk_project::popup_HtoMethyl },
+#endif	// ENABLE_OPENBABEL
+	{ "ConstrainMenu", NULL, "_Constrain" },
+	{ "ConstrainBondLength", NULL, "Atom Distances...", NULL, "Constrain Bond Length...", (GCallback) gtk_project::popup_ConstrainBondLength },
 	
 	{ "EnterCommand", NULL, "Enter a Command...", NULL, "...todo...", (GCallback) gtk_project::popup_EnterCommand },
 };
@@ -209,6 +229,12 @@ const char * gtk_graphics_view::ui_description =
 "        <menuitem action='SelectMolecules'/>"
 "      </menu>"
 "      <separator/>"
+"      <menuitem action='HideSelected'/>"
+"      <menuitem action='ShowSelected'/>"
+"      <separator/>"
+"      <menuitem action='LockSelected'/>"
+"      <menuitem action='UnlockSelected'/>"
+"      <separator/>"
 "      <menuitem action='DeleteSelected'/>"
 "    </menu>"
 "    <separator/>"
@@ -290,6 +316,15 @@ const char * gtk_graphics_view::ui_description =
 "      <menuitem action='ObjectsDeleteCurrent'/>"
 "    </menu>"
 "    <separator/>"
+#ifdef ENABLE_GAMESS
+"    <menu action='GamessMenu'>"
+"      <menuitem action='GamessInp'/>"
+#ifdef ENABLE_OPENBABEL
+"      <menuitem action='MarkQM'/>"
+"      <menuitem action='MarkEFP'/>"
+#endif  // ENABLE_OPENBABEL
+"    </menu>"
+#endif  // ENABLE_GAMESS
 "    <menu action='ComputeMenu'>"
 "      <menuitem action='CompSetup'/>"
 "      <separator/>"
@@ -319,6 +354,9 @@ const char * gtk_graphics_view::ui_description =
 "      <menu action='BuildHydrogensMenu'>"
 "        <menuitem action='BuildHydrogensAdd'/>"
 "        <menuitem action='BuildHydrogensRemove'/>"
+#ifdef ENABLE_OPENBABEL
+"        <menuitem action='BuildHydrogensHtoMethyl'/>"
+#endif	// ENABLE_OPENBABEL
 "      </menu>"
 "      <separator/>"
 "      <menuitem action='BuildSolvateBox'/>"
@@ -330,6 +368,9 @@ const char * gtk_graphics_view::ui_description =
 "      <menuitem action='BuildCenter'/>"
 "      <menuitem action='BuildClear'/>"
 "    </menu>"
+"    <menu action='ConstrainMenu'>"
+"      <menuitem action='ConstrainBondLength'/>"
+"    </menu>"
 "    <separator/>"
 "    <menuitem action='EnterCommand'/>"
 "  </popup>"
