@@ -34,14 +34,22 @@
 #include "setup_dialog.h"
 #include "progress_dialog.h"
 
+#ifdef ENABLE_GAMESS
+#include "efp_dialog.h"
+#include "gamess_dialog.h"
+#include "gamess.h"
+#endif  // ENABLE_GAMESS
+#include "constraint_dialog.h"
+
 #include "gtk_graphics_view.h"
+#include "gtk_project_view.h"
 
 #include <sys/stat.h>	// for stat
 #include <dirent.h>	// for scandir
 
 #include <glade/glade.h>
 
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -98,6 +106,10 @@ gtk_project::gtk_project(gtk_class_factory & p2) : project(p2)
 #ifdef ENABLE_THREADS
 	pd = NULL;
 #endif	// ENABLE_THREADS
+
+#ifdef ENABLE_GAMESS
+	gamess_data = new GamessData();
+#endif  // ENABLE_GAMESS
 	
 /*	GtkMenuItem * mi = GTK_MENU_ITEM(build_submenu[1].widget);
 	MakeLibraryWidgets(mi, "library/", 1);	*/
@@ -123,6 +135,10 @@ gtk_project::~gtk_project(void)
 	if (pd != NULL) cout << "MEM-LEAK pd" << endl;
 #endif	// ENABLE_THREADS
 
+#ifdef ENABLE_GAMESS
+	delete(gamess_data);
+#endif  // ENABLE_GAMESS
+
 }
 
 #ifdef ENABLE_BONOBO
@@ -244,12 +260,20 @@ bool gtk_project::Question(const char * msg)
 
 void gtk_project::PrintToLog(const char * message)
 {
+	static int msgcounter = 0;
+	static char msgbuff[4][1024];
+	
+	strcpy(msgbuff[msgcounter], message);
+	
 	GtkTextIter txt_iter;
 	gtk_text_buffer_get_iter_at_mark(txt_buffer, & txt_iter, end_mark);
 	
-	gtk_text_buffer_insert(txt_buffer, & txt_iter, message, -1);
+	gtk_text_buffer_insert(txt_buffer, & txt_iter, msgbuff[msgcounter], -1);
 	
 	gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(txt_widget), end_mark);
+	
+	cout << "PrintToLog[" << msgcounter << "] : " << message;
+	if (++msgcounter >= 4) msgcounter = 0;
 }
 
 void gtk_project::UpdateAllWindowTitles()
@@ -441,9 +465,29 @@ void gtk_project::popup_InvertSelection(GtkWidget *, gpointer data)
 	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->InvertSelection();
 }
 
-void gtk_project::popup_DeleteSelection(GtkWidget *, gpointer data)
+void gtk_project::popup_HideSelected(GtkWidget *, gpointer data)
 {
-	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->DeleteSelection();
+	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->HideSelected();
+}
+
+void gtk_project::popup_ShowSelected(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->ShowSelected();
+}
+
+void gtk_project::popup_LockSelected(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->LockSelected();
+}
+
+void gtk_project::popup_UnlockSelected(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->UnlockSelected();
+}
+
+void gtk_project::popup_DeleteSelected(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view::GetGV((GtkWidget *) data)->prj->DeleteSelected();
 }
 
 void gtk_project::popup_SelectModeAtom(GtkWidget *, gpointer data)
@@ -1067,6 +1111,124 @@ void gtk_project::popup_HRemove(GtkWidget *, gpointer data)
 	}
 }
 
+void gtk_project::popup_HtoMethyl(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+	
+#ifdef ENABLE_OPENBABEL
+	
+	if (prj)
+	{
+		prj->HtoMethyl();
+		prj->UpdateAllGraphicsViews();
+	}
+	
+#else	// ENABLE_OPENBABEL
+	
+	if (prj)
+	{
+		prj->Message("Sorry, this feature requres OpenBabel support.");
+	}
+	
+#endif	// ENABLE_OPENBABEL
+}
+
+#ifdef ENABLE_GAMESS
+void gtk_project::popup_GamessInp(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+	if (prj)
+	{
+		new gamess_dialog(prj);
+	}
+}
+
+// The EFP Stuff doesn't work without the babel toolkit!
+#ifdef ENABLE_OPENBABEL
+void gtk_project::popup_MarkQM(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+	if (prj)
+	{
+		new efp_dialog(prj, EFPGroup::QM);
+	}
+		/*
+		EFPGroup group;
+		group.SetType(TYPE_QM);
+		int count = 0;
+		for (iter_al it1 = prj->GetAtomsBegin();it1 != prj->GetAtomsEnd();it1++)
+		{
+			if ((*it1).GetSelected())
+			{
+				group.AddAtom((*it1));
+				count++;
+			}
+		}
+		
+		if( count == 0 )
+		{
+			prj->Message("Please select exactly two atoms\nfor adding a constraint.");
+			return;
+		}
+		else
+		{
+			// prj->gamess_data->GetEFPData()->AddGroup(group);
+			prj->AddEFPGroup(group);
+		}
+		*/
+}
+
+void gtk_project::popup_MarkEFP(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+
+	if (prj)
+	{
+		new efp_dialog(prj);
+	}
+
+	/*
+		EFPGroup group;
+		group.SetType(TYPE_EFP);
+		int count = 0;
+		for (iter_al it1 = prj->GetAtomsBegin();it1 != prj->GetAtomsEnd();it1++)
+		{
+			if ((*it1).GetSelected())
+			{
+				group.AddAtom((*it1));
+				count++;
+			}
+		}
+		
+		if( count == 0 )
+		{
+			prj->Message("Please select exactly two atoms\nfor adding a constraint.");
+			return;
+		}
+		else
+		{
+			// prj->gamess_data->GetEFPData()->AddGroup(group); 
+			prj->AddEFPGroup(group);
+		}
+	*/
+}
+#endif  // ENABLE_OPENBABEL
+#endif  // ENABLE_GAMESS
+
+void gtk_project::popup_ConstrainBondLength(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+	if (prj)
+	{
+		new constraint_dialog(prj);
+	}
+}
+
 void gtk_project::popup_SolvateBox(GtkWidget *, gpointer data)
 {
 	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
