@@ -22,7 +22,7 @@ class gtk_project;
 #include "gtk_views.h"
 
 #include "gtk_dialog.h"
-#include "glade/progress_dialog.h"
+#include "progress_dialog.h"
 
 #include <gtk/gtk.h>
 
@@ -30,6 +30,10 @@ class gtk_project;
 #include <bonobo.h>
 #endif	// ENABLE_BONOBO
 
+#ifdef ENABLE_GAMESS
+#include "gamess.h"
+#endif	// ENABLE_GAMESS
+
 #include <vector>
 using namespace std;
 
@@ -139,7 +143,12 @@ friend class gtk_ssc_view;
 	static void popup_SelectAll(GtkWidget *, gpointer);
 	static void popup_SelectNone(GtkWidget *, gpointer);
 	static void popup_InvertSelection(GtkWidget *, gpointer);
-	static void popup_DeleteSelection(GtkWidget *, gpointer);
+	
+	static void popup_HideSelected(GtkWidget *, gpointer);
+	static void popup_ShowSelected(GtkWidget *, gpointer);
+	static void popup_LockSelected(GtkWidget *, gpointer);
+	static void popup_UnlockSelected(GtkWidget *, gpointer);
+	static void popup_DeleteSelected(GtkWidget *, gpointer);
 	
 	static void popup_SelectModeAtom(GtkWidget *, gpointer data);
 	static void popup_SelectModeResidue(GtkWidget *, gpointer data);
@@ -199,15 +208,22 @@ friend class gtk_ssc_view;
 	static void popup_CompTransitionStateSearch(GtkWidget *, gpointer);
 	static void popup_CompStationaryStateSearch(GtkWidget *, gpointer);
 	static void popup_CompFormula(GtkWidget *, gpointer);
-static void popup_CompSetFormalCharge(GtkWidget *, gpointer);
-static void popup_CompCreateRS(GtkWidget *, gpointer);
-static void popup_CompCycleRS(GtkWidget *, gpointer);
+	static void popup_CompSetFormalCharge(GtkWidget *, gpointer);
+	static void popup_CompCreateRS(GtkWidget *, gpointer);
+	static void popup_CompCycleRS(GtkWidget *, gpointer);
 	
 	static void popup_TrajView(GtkWidget *, gpointer);
 	static void popup_SetOrbital(GtkWidget *, gpointer);
 	
 	static void popup_HAdd(GtkWidget *, gpointer);
 	static void popup_HRemove(GtkWidget *, gpointer);
+	static void popup_HtoMethyl(GtkWidget *, gpointer);
+#ifdef ENABLE_GAMESS
+	static void popup_GamessInp(GtkWidget *, gpointer);
+	static void popup_MarkQM(GtkWidget *, gpointer);
+	static void popup_MarkEFP(GtkWidget *, gpointer);
+#endif  // ENABLE_GAMESS
+	static void popup_ConstrainBondLength(GtkWidget *, gpointer);
 	static void popup_SolvateBox(GtkWidget *, gpointer);
 	static void popup_SolvateSphere(GtkWidget *, gpointer);
 	static void popup_Clear(GtkWidget *, gpointer);
