@@ -13,7 +13,7 @@
 
 #include <gtk/gtk.h>
 
-#include <strstream>
+#include <sstream>
 #include <algorithm>
 using namespace std;
 
@@ -22,6 +22,9 @@ using namespace std;
 // the views-menu...
 // ^^^^^^^^^^^^^^^^^
 
+const char * gtk_project_view::c_dst_type_value[] = { "None", "Min Only", "Max Only", "Min & Max" };
+const char * gtk_project_view::efp_type_value[] = { "EFP", "QM" };
+
 GtkActionEntry gtk_project_view::views_entries[] =
 {
 	{ "views_SetCurrent", NULL, "_Set to Current Object", "<control>S", "Set this object to Current Object", (GCallback) gtk_project_view::views_SetCurrent },
@@ -103,6 +106,40 @@ const char * gtk_project_view::bonds_ui_description =
 "  </popup>"
 "</ui>";
 
+// the constraints-menu...
+// ^^^^^^^^^^^^^^^^^
+
+GtkActionEntry gtk_project_view::c_dst_entries[] =
+{
+	{ "c_dst_DeleteConstraint", NULL, "_Delete Constraint", "<control>D", "Delete this constraint", (GCallback) gtk_project_view::c_dst_DeleteConstraint },
+};
+
+const char * gtk_project_view::c_dst_ui_description =
+"<ui>"
+"  <popup name='gpvConstraintsMenu'>"
+"    <menuitem action='c_dst_DeleteConstraint'/>"
+"  </popup>"
+"</ui>";
+
+#ifdef ENABLE_GAMESS
+
+// the efp-menu...
+// ^^^^^^^^^^^^^^^^^
+
+GtkActionEntry gtk_project_view::efp_entries[] =
+{
+	{ "efp_DeleteEFPGroup", NULL, "_Delete EFP", "<control>D", "Delete this EFP", (GCallback) gtk_project_view::efp_DeleteEFPGroup },
+};
+
+const char * gtk_project_view::efp_ui_description =
+"<ui>"
+"  <popup name='gpvEFPMenu'>"
+"    <menuitem action='efp_DeleteEFPGroup' />"
+"  </popup>"
+"</ui>";
+
+#endif  //ENABLE_GAMESS
+
 // other stuff...
 // ^^^^^^^^^^^^^^
 
@@ -239,7 +276,7 @@ g_signal_connect_swapped(GTK_OBJECT(chains_widget), "button_press_event", G_CALL
 	
 	// "atoms"-page
 	
-	atoms_store = gtk_list_store_new (2, G_TYPE_UINT, G_TYPE_STRING);
+	atoms_store = gtk_list_store_new (3, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_BOOLEAN);
 	atoms_widget = gtk_tree_view_new_with_model(GTK_TREE_MODEL(atoms_store));
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(atoms_widget), TRUE);	// optional : draw the stripes to background.
 	
@@ -251,6 +288,12 @@ g_signal_connect_swapped(GTK_OBJECT(chains_widget), "button_press_event", G_CALL
 	column = gtk_tree_view_column_new_with_attributes("Element", renderer, "text", 1, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(atoms_widget), column);
 	
+	renderer = gtk_cell_renderer_toggle_new();	// locked
+	g_object_set(renderer, "activatable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "toggled", G_CALLBACK(atoms_ToggleLocked), (gpointer) atoms_store);
+	column = gtk_tree_view_column_new_with_attributes("Locked", renderer, "active", 2, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(atoms_widget), column);
+	
 	atoms_label = gtk_label_new("Atoms");
 	atoms_sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(atoms_sw), GTK_SHADOW_ETCHED_IN);	// optional : ???
@@ -311,6 +354,139 @@ g_signal_connect_swapped(GTK_OBJECT(bonds_widget), "button_press_event", G_CALLB
 	gtk_widget_show(bonds_label);
 	gtk_widget_show(bonds_sw);
 	
+	// "constraints"-page
+	
+	c_dst_store = gtk_list_store_new (9, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_STRING, G_TYPE_BOOLEAN);
+	c_dst_widget = gtk_tree_view_new_with_model(GTK_TREE_MODEL(c_dst_store));
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(c_dst_widget), TRUE);
+	
+	renderer = gtk_cell_renderer_text_new();	// index1
+	column = gtk_tree_view_column_new_with_attributes("Atom 1", renderer, "text", 1, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_text_new();	// index2
+	column = gtk_tree_view_column_new_with_attributes("Atom 2", renderer, "text", 2, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_text_new();	// Min Length
+	g_object_set(renderer, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(c_dst_ModifyMinDistance), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Min Length (nm)", renderer, "text", 3, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_text_new();	// Min FC
+	g_object_set(renderer, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(c_dst_ModifyMinFC), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Min FC", renderer, "text", 4, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_text_new();	// Max Length
+	g_object_set(renderer, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(c_dst_ModifyMaxDistance), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Max Length (nm)", renderer, "text", 5, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_text_new();	// Max FC
+	g_object_set(renderer, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(c_dst_ModifyMaxFC), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Max FC", renderer, "text", 6, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_combo_new();	// Enable
+	c_dst_enum_store = gtk_list_store_new(2, G_TYPE_INT, G_TYPE_STRING);
+	GtkTreeIter iter;
+	for (int i = constraint_dst::Disabled;i <= constraint_dst::MinAndMax;i++)
+	{
+		gtk_list_store_append(c_dst_enum_store, &iter);
+		gtk_list_store_set(c_dst_enum_store, &iter, 0, i, 1, c_dst_type_value[i], -1);
+	}
+	g_object_set(renderer, "model", c_dst_enum_store, "text_column", 1, "has_entry", FALSE, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(c_dst_ModifyType), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Enable", renderer, "text", 7, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	renderer = gtk_cell_renderer_toggle_new();	// Skip MM Non-Bonded
+	g_object_set(renderer, "activatable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "toggled", G_CALLBACK(c_dst_ToggleSkipMMnb), (gpointer) c_dst_store);
+	column = gtk_tree_view_column_new_with_attributes("Skip MM NB", renderer, "active", 8, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(c_dst_widget), column);
+	
+	c_dst_label = gtk_label_new("Constraints");
+	c_dst_sw = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(c_dst_sw), GTK_SHADOW_ETCHED_IN);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(c_dst_sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_container_add(GTK_CONTAINER(c_dst_sw), c_dst_widget);
+	gtk_notebook_append_page(GTK_NOTEBOOK(view_widget), c_dst_sw, c_dst_label);
+action_group = gtk_action_group_new("gpvConstraintsActions");
+gtk_action_group_add_actions(action_group, c_dst_entries, G_N_ELEMENTS(c_dst_entries), GTK_WIDGET(c_dst_widget));
+gtk_ui_manager_insert_action_group(gtk_app::GetUIManager(), action_group, 0);
+error = NULL;
+if (!gtk_ui_manager_add_ui_from_string(gtk_app::GetUIManager(), c_dst_ui_description, -1, & error))
+{
+	g_message("Building gpv Constraints menu failed : %s", error->message);
+	g_error_free(error); exit(EXIT_FAILURE);
+}
+c_dst_menu = gtk_ui_manager_get_widget(gtk_app::GetUIManager(), "/gpvConstraintsMenu");
+g_signal_connect(GTK_OBJECT(c_dst_widget), "button_press_event", G_CALLBACK(PopupHandler), c_dst_menu);
+	
+	gtk_widget_show(c_dst_widget);
+	gtk_widget_show(c_dst_label);
+	gtk_widget_show(c_dst_sw);
+	
+#ifdef ENABLE_GAMESS
+#ifdef ENABLE_OPENBABEL
+	// "efp"-page
+	
+	efp_store = gtk_list_store_new (4, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+	efp_widget = gtk_tree_view_new_with_model(GTK_TREE_MODEL(efp_store));
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(efp_widget), TRUE);
+	
+	renderer = gtk_cell_renderer_text_new();	// label
+	g_object_set(renderer, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(efp_ModifyLabel), (gpointer) efp_store);
+	column = gtk_tree_view_column_new_with_attributes("Label", renderer, "text", 1, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(efp_widget), column);
+	
+	efp_type_store = gtk_list_store_new(2, G_TYPE_INT, G_TYPE_STRING);
+	for (int i = EFPGroup::EFP;i < EFPGroup::NUM_TYPES;i++)
+	{
+		gtk_list_store_append(efp_type_store, &iter);
+		gtk_list_store_set(efp_type_store, &iter, 0, i, 1, efp_type_value[i], -1);
+	}
+	renderer = gtk_cell_renderer_combo_new();	// type
+	g_object_set(renderer, "model", efp_type_store, "text_column", 1, "has_entry", FALSE, "editable", TRUE, NULL);
+	g_signal_connect(GTK_OBJECT(renderer), "edited", G_CALLBACK(efp_ModifyType), (gpointer) efp_store);
+	column = gtk_tree_view_column_new_with_attributes("Type", renderer, "text", 2, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(efp_widget), column);
+
+	renderer = gtk_cell_renderer_text_new();	// atoms
+	column = gtk_tree_view_column_new_with_attributes("Atoms", renderer, "text", 3, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(efp_widget), column);
+	
+	efp_label = gtk_label_new("EFP Info");
+	efp_sw = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(efp_sw), GTK_SHADOW_ETCHED_IN);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(efp_sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_container_add(GTK_CONTAINER(efp_sw), efp_widget);
+	gtk_notebook_append_page(GTK_NOTEBOOK(view_widget), efp_sw, efp_label);
+action_group = gtk_action_group_new("gpvEFPActions");
+gtk_action_group_add_actions(action_group, efp_entries, G_N_ELEMENTS(efp_entries), GTK_WIDGET(efp_widget));
+gtk_ui_manager_insert_action_group(gtk_app::GetUIManager(), action_group, 0);
+error = NULL;
+if (!gtk_ui_manager_add_ui_from_string(gtk_app::GetUIManager(), efp_ui_description, -1, & error))
+{
+	g_message("Building gpv EFP menu failed : %s", error->message);
+	g_error_free(error); exit(EXIT_FAILURE);
+}
+efp_menu = gtk_ui_manager_get_widget(gtk_app::GetUIManager(), "/gpvEFPMenu");
+g_signal_connect(GTK_OBJECT(efp_widget), "button_press_event", G_CALLBACK(PopupHandler), efp_menu);
+	
+	gtk_widget_show(efp_widget);
+	gtk_widget_show(efp_label);
+	gtk_widget_show(efp_sw);
+#endif  // ENABLE_OPENBABEL
+#endif  // ENABLE_GAMESS
+	
 	// initialize...
 	// initialize...
 	// initialize...
@@ -342,12 +518,12 @@ gtk_project_view * gtk_project_view::GetInstance(void)
 	return instance;
 }
 
-void gtk_project_view::Update(bool directly)
+void gtk_project_view::Update(bool)
 {
-	cout << "gtk_project_view::Update() called with param " << directly << endl;
-// how to handle update requests!??!?!
-// how to handle update requests!??!?!
-// how to handle update requests!??!?!
+	// there should really be no need to request the
+	// "project view" do display information, since the
+	// information is displayed using GTK widgets that
+	// update their contents automatically when needed.
 }
 
 void gtk_project_view::UpdateAllWindowTitles(void)
@@ -357,10 +533,10 @@ void gtk_project_view::UpdateAllWindowTitles(void)
 	{
 		if ((* it)->obj2 != NULL)
 		{
-			char object_name[256]; ostrstream ons(object_name, sizeof(object_name));
+			ostringstream ons;
 			ons << "graphics_view #" << (* it)->obj2->my_gv_number << ends;
 			
-			gtk_tree_store_set(views_store, & (* it)->iter, 0, object_name, 1, FALSE, -1);
+			gtk_tree_store_set(views_store, & (* it)->iter, 0, ons.str().c_str(), 1, FALSE, -1);
 		}
 		
 		it++;
@@ -449,10 +625,10 @@ void gtk_project_view::GraphicsViewAdded(graphics_view * gv)
 	
 	views_data.push_back(v_rec);
 	
-	char object_name[256]; ostrstream ons(object_name, sizeof(object_name));
+	ostringstream ons;
 	ons << "graphics_view #" << gv->my_gv_number << ends;
 	
-	gtk_tree_store_set(views_store, & v_rec->iter, 0, object_name, 1, FALSE, -1);
+	gtk_tree_store_set(views_store, & v_rec->iter, 0, ons.str().c_str(), 1, FALSE, -1);
 }
 
 void gtk_project_view::GraphicsViewRemoved(graphics_view * gv)
@@ -516,9 +692,10 @@ void gtk_project_view::views_SetCurrent(GtkWidget * widget, gpointer data)
 		{
 			gpv->prj->selected_object = (* it)->obj1;
 			
-			char message[256]; ostrstream mstr(message, sizeof(message));
+			ostringstream mstr;
 			mstr << "Object " << gpv->prj->selected_object->GetObjectName() << " is set to current object." << endl << ends;
-			gpv->prj->PrintToLog(message);
+			
+			gpv->prj->PrintToLog(mstr.str().c_str());
 		}
 		else gpv->prj->Message("Sorry, this is only for light objects!");
 	}
@@ -547,9 +724,10 @@ void gtk_project_view::views_Delete(GtkWidget *, gpointer data)
 		
 		if (is_light)
 		{
-			char message[256]; ostrstream mstr(message, sizeof(message));
+			ostringstream mstr;
 			mstr << "Object " << gpv->prj->selected_object->GetObjectName() << " is deleted." << endl << ends;
-			gpv->prj->PrintToLog(message);
+			
+			gpv->prj->PrintToLog(mstr.str().c_str());
 			
 			if (gpv->prj->selected_object == (* it)->obj1) gpv->prj->selected_object = NULL;
 			gpv->prj->RemoveLight((* it)->obj1);
@@ -563,9 +741,10 @@ void gtk_project_view::views_Delete(GtkWidget *, gpointer data)
 			{
 				gtk_graphics_view * ggv = dynamic_cast<gtk_graphics_view *>((* it)->obj2);
 				
-				char message[256]; ostrstream mstr(message, sizeof(message));
+				ostringstream mstr;
 				mstr << "View #" << ggv->my_gv_number << " is deleted." << endl << ends;
-				gpv->prj->PrintToLog(message);
+				
+				gpv->prj->PrintToLog(mstr.str().c_str());
 				
 				if (ggv->detached != NULL)
 				{
@@ -643,9 +822,11 @@ void gtk_project_view::objects_SetCurrent(GtkWidget *, gpointer data)
 		if (it == gpv->objects_data.end()) { cout << "ERROR : gtk_project_view::ObjectsEventHandler1() failed." << endl; exit(EXIT_FAILURE); }
 		
 		gpv->prj->selected_object = (* it)->obj;
-		char message[256]; ostrstream mstr(message, sizeof(message));
+		
+		ostringstream mstr;
 		mstr << "Object " << gpv->prj->selected_object->GetObjectName() << " is set to current object." << endl << ends;
-		gpv->prj->PrintToLog(message);
+		
+		gpv->prj->PrintToLog(mstr.str().c_str());
 	}
 }
 
@@ -667,9 +848,10 @@ void gtk_project_view::objects_Delete(GtkWidget *, gpointer data)
 		while (it != gpv->objects_data.end()) { if ((* it)->iter.user_data == iter.user_data) break; else it++; }
 		if (it == gpv->objects_data.end()) { cout << "ERROR : gtk_project_view::ObjectsEventHandler2() failed." << endl; exit(EXIT_FAILURE); }
 		
-		char message[256]; ostrstream mstr(message, sizeof(message));
+		ostringstream mstr;
 		mstr << "Object " << (* it)->obj->GetObjectName() << " is deleted." << endl << ends;
-		gpv->prj->PrintToLog(message);
+		
+		gpv->prj->PrintToLog(mstr.str().c_str());
 		
 		if (gpv->prj->selected_object == (* it)->obj) gpv->prj->selected_object = NULL;
 		gpv->prj->RemoveObject((* it)->obj);
@@ -696,8 +878,7 @@ void gtk_project_view::BuildChainsView(void)
 			
 			chains_data.push_back(c_rec1);
 			
-			char chain_info[256];
-			ostrstream cis(chain_info, sizeof(chain_info));
+			ostringstream cis;
 		//	if (ci_vector[n1].description...	// this not implemented at the moment...
 			cis << "chain #" << n1 << " (";
 			switch (ci_vector[n1].GetType())
@@ -708,9 +889,9 @@ void gtk_project_view::BuildChainsView(void)
 			}
 			cis << " chain)." << ends;
 			
-			gtk_tree_store_set(chains_store, & c_rec1->iter, 0, chain_info, 1, FALSE, 2, FALSE, 3, FALSE, 4, FALSE, -1);
+			gtk_tree_store_set(chains_store, & c_rec1->iter, 0, cis.str().c_str(), 1, FALSE, 2, FALSE, 3, FALSE, 4, FALSE, -1);
 			
-			const char * seq_buff = ci_vector[n1].GetSequence();
+			const char * seq1_buff = ci_vector[n1].GetSequence1();
 			for (i32s n2 = 0;n2 < ci_vector[n1].GetLength();n2++)
 			{
 				gpv_chains_record * c_rec2 = new gpv_chains_record;
@@ -718,10 +899,13 @@ void gtk_project_view::BuildChainsView(void)
 				
 				chains_data.push_back(c_rec2);
 				
-				char res_num[16]; ostrstream rns(res_num, sizeof(res_num)); rns << n2 << ends;
-				char res_id[8] = "?"; res_id[0] = seq_buff[n2];
+				ostringstream rns;
+				rns << n2 << ends;
 				
-				gtk_tree_store_set(chains_store, & c_rec2->iter, 0, FALSE, 1, res_num, 2, res_id, 3, "???", 4, "???", -1);
+				char res_id[8] = "?";
+				res_id[0] = seq1_buff[n2];
+				
+				gtk_tree_store_set(chains_store, & c_rec2->iter, 0, FALSE, 1, rns.str().c_str(), 2, res_id, 3, "???", 4, "???", -1);
 			}
 		}
 	}
@@ -815,7 +999,7 @@ void gtk_project_view::chains_SelectItem(GtkWidget *, gpointer data)
 		{
 			for (iter_al iter = c_rng[0]; iter != c_rng[1];iter++)
 			{
-				(* iter).flags |= ATOMFLAG_SELECTED;
+				(* iter).flags |= ATOMFLAG_USER_SELECTED;
 			}
 		}
 		else			// select residue
@@ -824,7 +1008,7 @@ void gtk_project_view::chains_SelectItem(GtkWidget *, gpointer data)
 			
 			for (iter_al iter = r_rng[0]; iter != r_rng[1];iter++)
 			{
-				(* iter).flags |= ATOMFLAG_SELECTED;
+				(* iter).flags |= ATOMFLAG_USER_SELECTED;
 			}
 		}
 		
@@ -850,8 +1034,9 @@ void gtk_project_view::AtomUpdateItem(atom * p1)
 	
 	i32s atmi = p1->index;
 	const char * ele = p1->el.GetSymbol();
+	const bool locked = p1->flags & ATOMFLAG_USER_LOCKED;
 	
-	gtk_list_store_set(atoms_store, & (* it)->iter, 0, atmi, 1, ele, -1);
+	gtk_list_store_set(atoms_store, & (* it)->iter, 0, atmi, 1, ele, 2, locked, -1);
 }
 
 void gtk_project_view::AtomRemoved(atom * p1)
@@ -900,11 +1085,32 @@ void gtk_project_view::atoms_SelectAtom(GtkWidget *, gpointer data)
 		while (it != gpv->atoms_data.end()) { if ((* it)->iter.user_data == iter.user_data) break; else it++; }
 		if (it == gpv->atoms_data.end()) { cout << "ERROR : gtk_project_view::AtomsEventHandler1() failed." << endl; exit(EXIT_FAILURE); }
 		
-		(* it)->ref->flags ^= ATOMFLAG_SELECTED;
+		(* it)->ref->flags ^= ATOMFLAG_USER_SELECTED;
 		gpv->prj->UpdateAllGraphicsViews();
 	}
 }
 
+gint gtk_project_view::atoms_ToggleLocked(GtkWidget * widget, gchar * path, gpointer data)
+{
+	gtk_project_view * gpv = GetInstance();
+	GtkTreeIter iter;
+	if(!gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path))
+	{ cout << "ERROR : gtk_project_view::atoms_ToggleLocked() failed." << endl; exit(EXIT_FAILURE); }
+	
+	list<gpv_atoms_record *>::iterator it = gpv->atoms_data.begin();
+	while (it != gpv->atoms_data.end()) { if ((* it)->iter.user_data == iter.user_data) break; else it++; }
+	if (it == gpv->atoms_data.end()) { cout << "ERROR : gtk_project_view::atoms_ToggleLocked() failed." << endl; exit(EXIT_FAILURE); }
+	
+	atom * p1 = (* it)->ref;
+	p1->SetLocked(!(p1->GetLocked()));
+	gtk_list_store_set(GTK_LIST_STORE(data), &iter, 2, p1->GetLocked(), -1);
+	
+	gpv->AtomUpdateItem(p1);	// make the list show updated information...
+	
+	// printf("Locked Changed: %s\n", p1->GetLocked() ? "true":"false");
+	return FALSE;
+}
+
 void gtk_project_view::BondAdded(bond * p1)
 {
 	gpv_bonds_record * b_rec = new gpv_bonds_record;
@@ -982,22 +1188,460 @@ void gtk_project_view::bonds_SelectBond(GtkWidget *, gpointer data)
 		while (it != gpv->bonds_data.end()) { if ((* it)->iter.user_data == iter.user_data) break; else it++; }
 		if (it == gpv->bonds_data.end()) { cout << "ERROR : gtk_project_view::BondsEventHandler1() failed." << endl; exit(EXIT_FAILURE); }
 		
-		bool both_selected = (((* it)->ref->atmr[0]->flags & ATOMFLAG_SELECTED) && ((* it)->ref->atmr[1]->flags & ATOMFLAG_SELECTED));
+		bool both_selected = (((* it)->ref->atmr[0]->flags & ATOMFLAG_USER_SELECTED) && ((* it)->ref->atmr[1]->flags & ATOMFLAG_USER_SELECTED));
 		if (!both_selected)	// select...
 		{
-			(* it)->ref->atmr[0]->flags |= ATOMFLAG_SELECTED;
-			(* it)->ref->atmr[1]->flags |= ATOMFLAG_SELECTED;
+			(* it)->ref->atmr[0]->flags |= ATOMFLAG_USER_SELECTED;
+			(* it)->ref->atmr[1]->flags |= ATOMFLAG_USER_SELECTED;
 		}
 		else			// un-select...
 		{
-			(* it)->ref->atmr[0]->flags &= (~ATOMFLAG_SELECTED);
-			(* it)->ref->atmr[1]->flags &= (~ATOMFLAG_SELECTED);
+			(* it)->ref->atmr[0]->flags &= (~ATOMFLAG_USER_SELECTED);
+			(* it)->ref->atmr[1]->flags &= (~ATOMFLAG_USER_SELECTED);
 		}
 		
 		gpv->prj->UpdateAllGraphicsViews();
 	}
 }
 
+// generic popup handler
+gint gtk_project_view::PopupHandler(GtkWidget * widget, GdkEvent * event, gpointer data)
+{
+	if (event->type == GDK_BUTTON_PRESS)
+	{
+		GdkEventButton * event_button = (GdkEventButton *) event;
+		if (event_button->button == 3)
+		{
+			// gtk_project_view * gpv = GetInstance(); 
+			GtkMenu *menu = GTK_MENU(data);
+			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, event_button->button, event_button->time);
+			return TRUE;
+		}
+	}
+	
+	return FALSE;
+}
+
+void gtk_project_view::ConstraintAdded(constraint_dst * p1)
+{
+	/* for now this function should go through all
+	 * the constraints.  why?  well, if two atoms are constrained
+	 * then they get new values, not really added, modified
+	 * and it doesn't make sense to check for that here.  there
+	 * needs to be a rethinking here anyways *shrug*
+	 */
+	GtkTreeIter iter;
+	gtk_project *prj = dynamic_cast<gtk_project*>(GetProject());
+	
+	gtk_list_store_clear(c_dst_store);
+	for(iter_CDl it1 = prj->GetConstD_begin();it1 != prj->GetConstD_end();it1++)
+	{
+		gtk_list_store_append(c_dst_store, & iter);
+		gtk_list_store_set(c_dst_store, & iter, 
+			0, & (* it1), 1, (* it1).atmr[0]->index, 2, (* it1).atmr[1]->index, 
+			3, (* it1).GetMinDist(), 4, (*it1).GetMinFC(), 
+			5, (* it1).GetMaxDist(), 6, (*it1).GetMaxFC(), 
+			7, c_dst_type_value[(* it1).GetType()], 8, (* it1).GetSkipMMnb(), -1);
+	}
+}
+
+void gtk_project_view::ConstraintUpdateItem(constraint_dst * p1)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gboolean valid;
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(c_dst_store), & iter);
+	
+	while (valid)
+	{
+		gtk_tree_model_get(GTK_TREE_MODEL(c_dst_store), & iter, 0, & c1, -1);
+		
+		if (* c1 == * p1)
+		{
+			gtk_list_store_set(c_dst_store, &iter, 
+				1, c1->atmr[0]->index, 2, c1->atmr[1]->index, 
+				3, c1->GetMinDist(), 4, c1->GetMinFC(), 
+				5, c1->GetMaxDist(), 6, c1->GetMaxFC(), 
+				7, c_dst_type_value[c1->GetType()], 8, c1->GetSkipMMnb(), -1);
+			break;
+		}
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(c_dst_store), & iter);
+	}
+}
+
+void gtk_project_view::ConstraintRemoved(constraint_dst * p1)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gboolean valid;
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(c_dst_store), & iter);
+	
+	while (valid)
+	{
+		gtk_tree_model_get(GTK_TREE_MODEL(c_dst_store), & iter, 0, & c1, -1);
+		
+		if (* c1 == * p1) valid = gtk_list_store_remove(c_dst_store, & iter);
+		else valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(c_dst_store), & iter);
+	}
+}
+
+void gtk_project_view::c_dst_ModifyMinDistance(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), & iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), & iter, 0, & c1, -1);
+	
+	c1->SetMinDist(atof(value));	// the distance is in nanometers ; no conversion.
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), & iter, 3, c1->GetMinDist(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_ModifyMinFC(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), & iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), & iter, 0, & c1, -1);
+	
+	c1->SetMinFC(atof(value));
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), & iter, 4, c1->GetMinFC(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_ModifyMaxDistance(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 0, &c1, -1);
+	
+	c1->SetMaxDist(atof(value));	// the distance is in nanometers ; no conversion.
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), & iter, 5, c1->GetMaxDist(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_ModifyMaxFC(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 0, &c1, -1);
+	
+	c1->SetMaxFC(atof(value));
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), &iter, 6, c1->GetMaxFC(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_ModifyType(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 0, &c1, -1);
+	
+	for( int i = constraint_dst::Disabled; i <= constraint_dst::MinAndMax; i++ )
+	{
+		if(!strcmp(c_dst_type_value[i], value))
+		{
+			c1->SetType((constraint_dst::type) i);
+			break;
+		}
+	}
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), &iter, 7, c_dst_type_value[c1->GetType()], -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_ToggleSkipMMnb(GtkWidget * widget, gchar * path, gpointer data)
+{
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 0, &c1, -1);
+	
+	c1->SetSkipMMnb(!c1->GetSkipMMnb());
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), &iter, 8, c1->GetSkipMMnb(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::c_dst_DeleteConstraint(GtkWidget * widget, gpointer data)
+{
+	gtk_project_view * gpv = GetInstance();
+
+	GtkTreeSelection * sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(data));
+
+	// this call is the same as model = GK_TREE_MODEL(gpv->c_dst_store)
+	// we don't even need this anyways, we get it from the gk_tree_selection_get_selected
+	//GtkTreeModel * model = gtk_tree_view_get_model(GTK_TREE_VIEW(data)); 
+	
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	constraint_dst * c1;
+	
+// assume that tsel is in mode GTK_SELECTION_SINGLE (as it seems to be); this is the simplest case...
+// here the equivalence test of GtkTreeIter is a bit uncertain... need to test any other records???
+	
+	bool has_item = gtk_tree_selection_get_selected(sel, & model, & iter);
+	if (has_item)
+	{
+		gtk_tree_model_get(model, &iter, 0, &c1, -1);
+		
+// printf("got c1: %d %d %f\n", c1->atmr[0]->index, c1->atmr[1]->index, c1->GetMinDist());
+		
+		// *sigh* we have to find the iterator to remove
+		for( iter_CDl it1 = gpv->prj->GetConstD_begin();it1 != gpv->prj->GetConstD_end();)
+		{
+			// tell our project to remove the constraint
+			if( c1 == &(* it1) )
+			{
+				gpv->prj->RemoveConstraint(it1); 
+				it1 = gpv->prj->GetConstD_begin();
+			}
+			else
+			{
+				it1++;
+			}
+		}
+	}
+}
+
+#ifdef ENABLE_GAMESS
+void gtk_project_view::EFPGroupAdded(EFPGroup* p1)
+{
+	printf("Group Added\n");
+
+	GtkTreeIter iter;
+	gtk_project *prj = dynamic_cast<gtk_project*>(GetProject());
+	char *s1, *s2;
+
+	gtk_list_store_clear(efp_store);
+	for(iter_efpgl it1 = prj->gamess_data->GetEFPData()->GetGroupBegin();
+			it1 != prj->gamess_data->GetEFPData()->GetGroupEnd();
+			it1++)
+	{
+		s1 = g_strconcat("", NULL);
+		gtk_list_store_append(efp_store, & iter);
+		gtk_list_store_set(efp_store, & iter, 
+			0, & (* it1), 1, (*it1).GetLabel().c_str(), 2, (*it1).GetTypeString(), 3, (*it1).GetAtomListString(","),-1
+			);
+	}
+	
+}
+
+void gtk_project_view::EFPGroupUpdateItem(EFPGroup * p1)
+{
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	gboolean valid;
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(efp_store), & iter);
+	
+	while (valid)
+	{
+		gtk_tree_model_get(GTK_TREE_MODEL(efp_store), & iter, 0, & g1, -1);
+		
+		if ( g1 == p1)
+		{
+			gtk_list_store_set(efp_store, & iter, 
+				0, & (* g1), 1, (*g1).GetLabel().c_str(), 2, (*g1).GetTypeString(), 3, (*g1).GetAtomListString(","),-1
+				);
+			break;
+		}
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(efp_store), & iter);
+	}
+}
+
+void gtk_project_view::EFPGroupRemoved(EFPGroup * p1)
+{
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	gboolean valid;
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(efp_store), & iter);
+
+	while (valid)
+	{
+		gtk_tree_model_get(GTK_TREE_MODEL(efp_store), & iter, 0, & g1, -1);
+
+		if (g1 ==  p1) valid = gtk_list_store_remove(efp_store, & iter);
+		else valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(efp_store), & iter);
+	}
+}
+
+void gtk_project_view::efp_DeleteEFPGroup(GtkWidget * widget, gpointer data)
+{
+	gtk_project_view * gpv = GetInstance();
+
+	GtkTreeSelection * sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(data));
+
+	// this call is the same as model = GK_TREE_MODEL(gpv->c_dst_store)
+	// we don't even need this anyways, we get it from the gk_tree_selection_get_selected
+	//GtkTreeModel * model = gtk_tree_view_get_model(GTK_TREE_VIEW(data)); 
+	
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	
+// assume that tsel is in mode GTK_SELECTION_SINGLE (as it seems to be); this is the simplest case...
+// here the equivalence test of GtkTreeIter is a bit uncertain... need to test any other records???
+	
+	bool has_item = gtk_tree_selection_get_selected(sel, & model, & iter);
+	if (has_item)
+	{
+		gtk_tree_model_get(model, &iter, 0, &g1, -1);
+		
+// printf("got g1: %d %d %f\n", g1->atmr[0]->index, g1->atmr[1]->index, g1->GetMinDist());
+		
+		// *sigh* we have to find the iterator to remove
+		for( iter_efpgl it1 = gpv->prj->gamess_data->GetEFPData()->GetGroupBegin();
+				it1 != gpv->prj->gamess_data->GetEFPData()->GetGroupEnd();)
+		{
+			// tell our project to remove the constraint
+			if( g1 == &(* it1) )
+			{
+				gpv->prj->RemoveEFPGroup(it1); 
+				it1 = gpv->prj->gamess_data->GetEFPData()->GetGroupBegin();
+			}
+			else
+			{
+				it1++;
+			}
+		}
+	}
+}
+
+void gtk_project_view::efp_ModifyLabel(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), & iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), & iter, 0, & g1, -1);
+	
+	g1->SetLabel(value);	// the distance is in nanometers ; no conversion.
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), & iter, 1, g1->GetLabel().c_str(), -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+void gtk_project_view::efp_ModifyType(GtkWidget * widget, gchar * path, gchar * value, gpointer data)
+{
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	gtk_project_view * gpv = GetInstance();
+	
+	gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(data), &iter, path);
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(data), &iter, 0, &g1, -1);
+	
+	for( int i = EFPGroup::EFP; i < EFPGroup::NUM_TYPES; i++ )
+	{
+		if(!strcmp(efp_type_value[i], value))
+		{
+			g1->SetType((EFPGroup::type) i);
+			break;
+		}
+	}
+	
+	gtk_list_store_set(GTK_LIST_STORE(data), &iter, 2, efp_type_value[g1->GetType()], -1);
+	
+	// we have to do this because our project has no function to update constraints
+	// TODO: add functionality prj->UpdateConstraint( c1, val )
+	gpv->prj->SystemWasModified();
+}
+
+/*
+void gtk_project_view::efp_DeleteAllEFPGroup(GtkWidget * widget, gpointer data)
+{
+	gtk_project_view * gpv = GetInstance();
+
+	GtkTreeSelection * sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(data));
+
+	// this call is the same as model = GK_TREE_MODEL(gpv->c_dst_store)
+	// we don't even need this anyways, we get it from the gk_tree_selection_get_selected
+	//GtkTreeModel * model = gtk_tree_view_get_model(GTK_TREE_VIEW(data)); 
+	
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	EFPGroup * g1;
+	
+// assume that tsel is in mode GTK_SELECTION_SINGLE (as it seems to be); this is the simplest case...
+// here the equivalence test of GtkTreeIter is a bit uncertain... need to test any other records???
+	
+	bool has_item = gtk_tree_selection_get_selected(sel, & model, & iter);
+	if (has_item)
+	{
+		gtk_tree_model_get(model, &iter, 0, &g1, -1);
+		
+// printf("got g1: %d %d %f\n", g1->atmr[0]->index, g1->atmr[1]->index, g1->GetMinDist());
+		
+		// *sigh* we have to find the iterator to remove
+		for( iter_efpgl it1 = gpv->prj->gamess_data->GetEFPData()->GetGroupBegin();
+				it1 != gpv->prj->gamess_data->GetEFPData()->GetGroupEnd();)
+		{
+			// tell our project to remove the constraint
+			if( g1 == &(* it1) )
+			{
+				gpv->prj->RemoveEFPGroup(it1); 
+				it1 = gpv->prj->gamess_data->GetEFPData()->GetGroupBegin();
+			}
+			else
+			{
+				it1++;
+			}
+		}
+	}
+}
+*/
+
+#endif  // ENABLE_GAMESS
+
+
 /*################################################################################################*/
 
 // eof
