@@ -81,8 +81,19 @@ class gtk_project_view : public gtk_view, public project_view
 	static GtkActionEntry bonds_entries[];
 	static const char * bonds_ui_description;
 	
+	static GtkActionEntry c_dst_entries[];
+	static const char * c_dst_ui_description;
+	
+#ifdef ENABLE_GAMESS
+	static GtkActionEntry efp_entries[];
+	static const char * efp_ui_description;
+#endif  // ENABLE_GAMESS
+	
 	static gtk_project_view * instance;		///< in an SDI GUI we only need a single view...
 	
+	static const char * c_dst_type_value[];
+	static const char * efp_type_value[];
+	
 	list<gpv_views_record *> views_data;
 	GtkTreeStore * views_store;
 	GtkWidget * views_widget;
@@ -118,12 +129,28 @@ GtkWidget * atoms_menu;
 GtkWidget * bonds_menu;
 	GtkWidget * bonds_sw;
 	
+	GtkListStore * c_dst_store;
+	GtkListStore * c_dst_enum_store;
+	GtkWidget * c_dst_widget;
+	GtkWidget * c_dst_label;
+GtkWidget * c_dst_menu;
+	GtkWidget * c_dst_sw;
+	
+#ifdef ENABLE_GAMESS
+	GtkListStore * efp_store;
+	GtkListStore * efp_type_store;
+	GtkWidget * efp_widget;
+	GtkWidget * efp_label;
+GtkWidget * efp_menu;
+	GtkWidget * efp_sw;
+#endif  // ENABLE_GAMESS
+	
 	private:
 	
 	gtk_project_view(gtk_project *);
 	
 	friend class gtk_class_factory;
-		
+	
 	public:
 	
 	~gtk_project_view(void);
@@ -162,12 +189,34 @@ GtkWidget * bonds_menu;
 	void AtomRemoved(atom *);			// virtual
 	static gint AtomsPopupHandler(GtkWidget *, GdkEvent *);
 	static void atoms_SelectAtom(GtkWidget *, gpointer);
+	static gint atoms_ToggleLocked(GtkWidget *, gchar *, gpointer);
 	
 	void BondAdded(bond *);				// virtual
 	void BondUpdateItem(bond *);			// virtual
 	void BondRemoved(bond *);			// virtual
 	static gint BondsPopupHandler(GtkWidget *, GdkEvent *);
 	static void bonds_SelectBond(GtkWidget *, gpointer);
+	
+	void ConstraintAdded(constraint_dst *);		// virtual
+	void ConstraintUpdateItem(constraint_dst *);	// virtual
+	void ConstraintRemoved(constraint_dst *);	// virtual
+	static gint PopupHandler(GtkWidget *, GdkEvent *, gpointer);
+	static void c_dst_ModifyMinDistance(GtkWidget * , gchar *, gchar *, gpointer );
+	static void c_dst_ModifyMinFC(GtkWidget * , gchar *, gchar *, gpointer );
+	static void c_dst_ModifyMaxDistance(GtkWidget * , gchar *, gchar *, gpointer );
+	static void c_dst_ModifyMaxFC(GtkWidget * , gchar *, gchar *, gpointer );
+	static void c_dst_ModifyType(GtkWidget * , gchar *, gchar *, gpointer );
+	static void c_dst_ToggleSkipMMnb(GtkWidget * , gchar *, gpointer );
+	static void c_dst_DeleteConstraint(GtkWidget *, gpointer);
+
+#ifdef ENABLE_GAMESS
+	void EFPGroupAdded(EFPGroup *);		// virtual
+	void EFPGroupUpdateItem(EFPGroup *); //virtual
+	void EFPGroupRemoved(EFPGroup *);	// virtual
+	static void efp_ModifyLabel(GtkWidget * widget, gchar * path, gchar * value, gpointer data);
+	static void efp_ModifyType(GtkWidget * widget, gchar * path, gchar * value, gpointer data);
+	static void efp_DeleteEFPGroup(GtkWidget *, gpointer);
+#endif  // ENABLE_GAMESS
 };
 
 /*################################################################################################*/
