@@ -22,7 +22,7 @@
 
 #include <gtk/gtk.h>
 
-#include <strstream>
+#include <sstream>
 #include <algorithm>
 using namespace std;
 
@@ -62,11 +62,10 @@ void gtk_view::SetTitle(const char * p1)
 		char projfilename[256];
 		prj->GetProjectFileName(projfilename, 256, true);
 		
-		char extended_title[256];
-		ostrstream str(extended_title, sizeof(extended_title));
+		ostringstream str;
 		str << projfilename << " : " << p1 << ends;
 		
-		gtk_window_set_title(GTK_WINDOW(gv->detached), extended_title);
+		gtk_window_set_title(GTK_WINDOW(gv->detached), str.str().c_str());
 		return;
 	}	*/
 	
