@@ -11,7 +11,16 @@
 
 #include "notice.h"
 
-#include "glade/setup_dialog.h"
+#include "setup_dialog.h"
+
+#include "ghemicalconfig.h"
+
+#ifdef ENABLE_SHORTCUTS
+#ifdef ENABLE_GAMESS
+#include "gamess_dialog.h"
+#endif  // ENABLE_GAMESS
+#include "constraint_dialog.h"
+#endif  // ENABLE_SHORTCUTS
 
 #include <ghemical/utility.h>
 
@@ -34,8 +43,22 @@
 #include "pixmaps/element.xpm"
 #include "pixmaps/bondtype.xpm"
 #include "pixmaps/setup.xpm"
+#ifdef ENABLE_SHORTCUTS
+#ifdef ENABLE_GAMESS
+#include "pixmaps/gamess.xpm"
+#endif  // ENABLE_GAMESS
+#include "pixmaps/addh.xpm"
+#include "pixmaps/removeh.xpm"
+#include "pixmaps/geomopt.xpm"
+#include "pixmaps/import.xpm"
+#include "pixmaps/invert.xpm"
+#include "pixmaps/none.xpm"
+#include "pixmaps/lock.xpm"
+#include "pixmaps/unlock.xpm"
+#include "pixmaps/constrain.xpm"
+#endif  // ENABLE_SHORTCUTS
 
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -46,6 +69,62 @@ using namespace std;
 gtk_app * gtk_app::instance = NULL;
 gtk_project * gtk_app::prj = NULL;
 
+const char * tb_mousetool_labels[] =
+#ifndef USE_SHORT_TOOLBAR_LABELS
+{
+	"draw\n",	"erase\n",	"select\n",	"zoom\n",	"clip\n",
+	"trans\nXY",	"trans\nZ",	"orbit\nXY",	"orbit\nZ",	"rotate\nXY",
+	"rotate\nZ",	"measure\n",	NULL
+};
+#else	// USE_SHORT_TOOLBAR_LABELS
+{
+	"d",		"e",		"s",		"z",		"c",
+	"t",		"tz",		"o",		"oz",		"r",
+	"rz",		"m",		NULL
+};
+#endif	// USE_SHORT_TOOLBAR_LABELS
+
+const char * tb_shortcut_labels[] =
+#ifndef USE_SHORT_TOOLBAR_LABELS
+{
+	"element\n",	"bond\ntype",	"setup\n",	
+#ifdef ENABLE_SHORTCUTS
+	"geometry\noptimization",
+	"add\nhydrogens",
+	"remove\nhydrogens",
+	"select\nall",
+	"invert\nselection\n",
+	"select\nnone",
+	"lock\nselected",
+	"unlock\nselected",
+	"constrain\nbond",
+#ifdef ENABLE_GAMESS
+	"gamess\n",
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
+	NULL
+};
+#else	// USE_SHORT_TOOLBAR_LABELS
+{
+	"el",		"bt",		"su",
+#ifdef ENABLE_SHORTCUTS
+	"go",
+	"aH",
+	"rH",
+	"sa",
+	"is",
+	"sn",
+	"ls",
+	"us",
+	"cbl",
+#ifdef ENABLE_GAMESS
+	"gms",
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
+	NULL
+};
+#endif	// USE_SHORT_TOOLBAR_LABELS
+
 GtkActionEntry gtk_app::entries1[] =
 {
 	{ "FileMenu", NULL, "_File" },
@@ -61,25 +140,39 @@ GtkActionEntry gtk_app::entries1[] =
 	// the rest are toolbar actions...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
-	{ "Element", "MY_ELEMENT_ICON", "el", NULL, "Set the current element", (GCallback) gtk_app::maintb_dial_Element },
-	{ "BondType", "MY_BONDTYPE_ICON", "bt", NULL, "Set the current bondtype", (GCallback) gtk_app::maintb_dial_BondType },
-	{ "Setup", "MY_SETUP_ICON", "su", NULL, "Setup or change the comp.chem. method in use", (GCallback) gtk_app::maintb_dial_Setup }
+	{ "Element", "MY_ELEMENT_ICON", tb_shortcut_labels[0], NULL, "Set the current element.", (GCallback) gtk_app::maintb_dial_Element },
+	{ "BondType", "MY_BONDTYPE_ICON", tb_shortcut_labels[1], NULL, "Set the current bondtype.", (GCallback) gtk_app::maintb_dial_BondType },
+	{ "Setup", "MY_SETUP_ICON", tb_shortcut_labels[2], NULL, "Setup or change the comp.chem. method in use.", (GCallback) gtk_app::maintb_dial_Setup }
+#ifdef ENABLE_SHORTCUTS
+	, { "Geomopt", "MY_GEOMOPT_ICON", tb_shortcut_labels[3], NULL, "Geometry Optimization.", (GCallback) gtk_app::shortcutstb_dial_Geomopt }
+	, { "AddH", "MY_ADDH_ICON", tb_shortcut_labels[4], NULL, "Add H ; Add Hydrogens.", (GCallback) gtk_app::shortcutstb_action_AddH }
+	, { "RemoveH", "MY_REMOVEH_ICON", tb_shortcut_labels[5], NULL, "Remove H ; Remove Hydrogens.", (GCallback) gtk_app::shortcutstb_action_RemoveH }
+	, { "SelectAll", "MY_SELECT_ICON", tb_shortcut_labels[6], NULL, "Select All ; Select all atoms.", (GCallback) gtk_app::shortcutstb_action_SelectAll }
+	, { "InvertSelection", "MY_INVERT_ICON", tb_shortcut_labels[7], NULL, "Invert Selection ; De-select selected atoms and vice versa.", (GCallback) gtk_app::shortcutstb_action_InvertSelection }
+	, { "SelectNone", "MY_NONE_ICON", tb_shortcut_labels[8], NULL, "Select None ; De-select all atoms.", (GCallback) gtk_app::shortcutstb_action_SelectNone }
+	, { "LockSelected", "MY_LOCK_ICON", tb_shortcut_labels[9], NULL, "Lock Selection ; Lock selected atoms.", (GCallback) gtk_app::shortcutstb_action_LockSelected }
+	, { "UnlockSelected", "MY_UNLOCK_ICON", tb_shortcut_labels[10], NULL, "Unlock Selection ; Unlock selected atoms.", (GCallback) gtk_app::shortcutstb_action_UnlockSelected }
+	, { "ConstrainBondLength", "MY_CONSTRAIN_ICON", tb_shortcut_labels[11], NULL, "Constrain Bond Length ; Add a distance constraint for a pair of selected atoms.", (GCallback) gtk_app::shortcutstb_dial_ConstrainBondLength }
+#ifdef ENABLE_GAMESS
+	, { "Gamess", "MY_GAMESS_ICON", tb_shortcut_labels[12], NULL, "Gamess ; Generate GAMESS Input Deck.", (GCallback) gtk_app::shortcutstb_dial_Gamess }
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
 };
 
 GtkToggleActionEntry gtk_app::entries2[] =
 {
-	{ "Draw", "MY_DRAW_ICON", "d", NULL, "Draw ; add atoms and bonds to the model.", (GCallback) gtk_app::maintb_tool_Draw, FALSE },
-	{ "Erase", "MY_ERASE_ICON", "e", NULL, "Erase ; remove atoms and bonds from the model.", (GCallback) gtk_app::maintb_tool_Erase, FALSE },
-	{ "Select", "MY_SELECT_ICON", "s", NULL, "Select ; make selections in the model, and also select objects.", (GCallback) gtk_app::maintb_tool_Select, FALSE },
-	{ "Zoom", "MY_ZOOM_ICON", "z", NULL, "Zoom ; zoom the view.", (GCallback) gtk_app::maintb_tool_Zoom, FALSE },
-	{ "Clip", "MY_CLIPPING_ICON", "c", NULL, "Clipping ; set the near and far clipping planes for graphics rendering.", (GCallback) gtk_app::maintb_tool_Clipping, FALSE },
-	{ "TransXY", "MY_TRANSL_XY_ICON", "t", NULL, "TranslateXY ; translate the camera or a selected object in XY-direction.", (GCallback) gtk_app::maintb_tool_TranslXY, FALSE },
-	{ "TransZ", "MY_TRANSL_Z_ICON", "tz", NULL, "TranslateZ ; translate the camera or a selected object in Z-direction.", (GCallback) gtk_app::maintb_tool_TranslZ, FALSE },
-	{ "OrbXY", "MY_ORBIT_XY_ICON", "o", NULL, "OrbitXY ; orbit the camera or a selected object around the focus point in XY-direction.", (GCallback) gtk_app::maintb_tool_OrbitXY, TRUE },
-	{ "OrbZ", "MY_ORBIT_Z_ICON", "oz", NULL, "OrbitZ ; orbit the camera or a selected object around the focus point in Z-direction.", (GCallback) gtk_app::maintb_tool_OrbitZ, FALSE },
-	{ "RotXY", "MY_ROTATE_XY_ICON", "r", NULL, "RotateXY ; turn the camera or a selected object in XY-direction.", (GCallback) gtk_app::maintb_tool_RotateXY, FALSE },
-	{ "RotZ", "MY_ROTATE_Z_ICON", "rz", NULL, "RotateZ ; turn the camera or a selected object in Z-direction.", (GCallback) gtk_app::maintb_tool_RotateZ, FALSE },
-	{ "Measure", "MY_MEASURE_ICON", "m", NULL, "Measure ; measure distances, angles and torsions.", (GCallback) gtk_app::maintb_tool_Measure, FALSE },
+	{ "Draw", "MY_DRAW_ICON", tb_mousetool_labels[0], NULL, "Draw ; add atoms and bonds to the model.", (GCallback) gtk_app::maintb_tool_Draw, FALSE },
+	{ "Erase", "MY_ERASE_ICON", tb_mousetool_labels[1], NULL, "Erase ; remove atoms and bonds from the model.", (GCallback) gtk_app::maintb_tool_Erase, FALSE },
+	{ "Select", "MY_SELECT_ICON", tb_mousetool_labels[2], NULL, "Select ; make selections in the model, and also select objects.", (GCallback) gtk_app::maintb_tool_Select, FALSE },
+	{ "Zoom", "MY_ZOOM_ICON", tb_mousetool_labels[3], NULL, "Zoom ; zoom the view.", (GCallback) gtk_app::maintb_tool_Zoom, FALSE },
+	{ "Clip", "MY_CLIPPING_ICON", tb_mousetool_labels[4], NULL, "Clipping ; set the near and far clipping planes for graphics rendering.", (GCallback) gtk_app::maintb_tool_Clipping, FALSE },
+	{ "TransXY", "MY_TRANSL_XY_ICON", tb_mousetool_labels[5], NULL, "TranslateXY ; translate the camera or a selected object in XY-direction.", (GCallback) gtk_app::maintb_tool_TranslXY, FALSE },
+	{ "TransZ", "MY_TRANSL_Z_ICON", tb_mousetool_labels[6], NULL, "TranslateZ ; translate the camera or a selected object in Z-direction.", (GCallback) gtk_app::maintb_tool_TranslZ, FALSE },
+	{ "OrbXY", "MY_ORBIT_XY_ICON", tb_mousetool_labels[7], NULL, "OrbitXY ; orbit the camera or a selected object around the focus point in XY-direction.", (GCallback) gtk_app::maintb_tool_OrbitXY, TRUE },
+	{ "OrbZ", "MY_ORBIT_Z_ICON", tb_mousetool_labels[8], NULL, "OrbitZ ; orbit the camera or a selected object around the focus point in Z-direction.", (GCallback) gtk_app::maintb_tool_OrbitZ, FALSE },
+	{ "RotXY", "MY_ROTATE_XY_ICON", tb_mousetool_labels[9], NULL, "RotateXY ; turn the camera or a selected object in XY-direction.", (GCallback) gtk_app::maintb_tool_RotateXY, FALSE },
+	{ "RotZ", "MY_ROTATE_Z_ICON", tb_mousetool_labels[10], NULL, "RotateZ ; turn the camera or a selected object in Z-direction.", (GCallback) gtk_app::maintb_tool_RotateZ, FALSE },
+	{ "Measure", "MY_MEASURE_ICON", tb_mousetool_labels[11], NULL, "Measure ; measure distances, angles and torsions.", (GCallback) gtk_app::maintb_tool_Measure, FALSE },
 };
 
 const char * gtk_app::ui_description =
@@ -119,6 +212,28 @@ const char * gtk_app::ui_description =
 "      <separator/>"
 "    </placeholder>"
 "  </toolbar>"
+#ifdef ENABLE_SHORTCUTS
+"  <toolbar name='ShortcutsTB'>"
+"    <placeholder name='MainShortcuts'>"
+"      <separator/>"
+"      <toolitem name='sa' action='SelectAll'/>"
+"      <toolitem name='si' action='InvertSelection'/>"
+"      <toolitem name='sn' action='SelectNone'/>"
+"      <separator/>"
+"      <toolitem name='ls' action='LockSelected'/>"
+"      <toolitem name='us' action='UnlockSelected'/>"
+"      <toolitem name='cbl' action='ConstrainBondLength'/>"
+"      <separator/>"
+"      <toolitem name='addh' action='AddH'/>"
+"      <toolitem name='rmh' action='RemoveH'/>"
+"      <separator/>"
+"      <toolitem name='gopt' action='Geomopt'/>"
+#ifdef ENABLE_GAMESS
+"      <toolitem name='gms' action='Gamess'/>"
+#endif  // ENABLE_GAMESS
+"    </placeholder>"
+"  </toolbar>"
+#endif  // ENABLE_SHORTCUTS
 "</ui>";
 
 GtkUIManager * gtk_app::ui_manager = NULL;
@@ -128,6 +243,9 @@ GtkWidget * gtk_app::main_vbox = NULL;
 
 GtkWidget * gtk_app::main_menubar = NULL;
 GtkWidget * gtk_app::main_toolbar = NULL;
+#ifdef ENABLE_SHORTCUTS
+GtkWidget * gtk_app::shortcuts_toolbar = NULL;
+#endif  // ENABLE_SHORTCUTS
 
 GtkWidget * gtk_app::mtb_mtool_draw = NULL;
 GtkWidget * gtk_app::mtb_mtool_erase = NULL;
@@ -160,7 +278,14 @@ gtk_app::gtk_app(void)
 	
 	GtkIconFactory * icon_factory = gtk_icon_factory_new();
 	GtkIconSet * icon_set; GdkPixbuf * pixbuf; GtkIconSource * icon_source;
-	const int num_icons = 12 + 3;
+	const int num_icons = 12 + 3
+#ifdef ENABLE_SHORTCUTS
+		+ 9
+#ifdef ENABLE_GAMESS
+		+ 1
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
+	;
 	
 	const char ** icondata[num_icons] =
 	{
@@ -180,6 +305,20 @@ gtk_app::gtk_app(void)
 		(const char **) element_xpm,
 		(const char **) bondtype_xpm,
 		(const char **) setup_xpm
+#ifdef ENABLE_SHORTCUTS
+		, (const char **) addh_xpm
+		, (const char **) removeh_xpm
+		, (const char **) geomopt_xpm
+		, (const char **) import_xpm
+		, (const char **) invert_xpm
+		, (const char **) none_xpm
+		, (const char **) lock_xpm
+		, (const char **) unlock_xpm
+		, (const char **) constrain_xpm
+#ifdef ENABLE_GAMESS
+		, (const char **) gamess_xpm
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
 	};
 	
 	const char * icon_id[num_icons] =
@@ -200,6 +339,20 @@ gtk_app::gtk_app(void)
 		"MY_ELEMENT_ICON",
 		"MY_BONDTYPE_ICON",
 		"MY_SETUP_ICON"
+#ifdef ENABLE_SHORTCUTS
+		, "MY_ADDH_ICON"
+		, "MY_REMOVEH_ICON"
+		, "MY_GEOMOPT_ICON"
+		, "MY_IMPORT_ICON"
+		, "MY_INVERT_ICON"
+		, "MY_NONE_ICON"
+		, "MY_LOCK_ICON"
+		, "MY_UNLOCK_ICON"
+		, "MY_CONSTRAIN_ICON"
+#ifdef ENABLE_GAMESS
+		, "MY_GAMESS_ICON"
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
 	};
 	
 	for (int ii = 0;ii < num_icons;ii++)
@@ -215,13 +368,36 @@ gtk_app::gtk_app(void)
 		gtk_icon_factory_add(icon_factory, icon_id[ii], icon_set);
 		gtk_icon_set_unref (icon_set);
 	}
-	
+
 	gtk_icon_factory_add_default(icon_factory);
 	
 	// create the main window...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^
 	
 	main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	
+#ifndef USE_SHORT_TOOLBAR_LABELS
+gtk_window_set_default_size(GTK_WINDOW(main_window), 845, 640);
+#else	// USE_SHORT_TOOLBAR_LABELS
+gtk_window_set_default_size(GTK_WINDOW(main_window), 620, 450);
+#endif	// USE_SHORT_TOOLBAR_LABELS
+
+gchar * tmp_title = g_strconcat("Ghemical", " ", PACKAGE_VERSION, NULL );
+gtk_window_set_title(GTK_WINDOW(main_window), tmp_title);
+free(tmp_title); tmp_title = NULL;
+
+	ostringstream str;
+	str << APPDATA_PATH << DIR_SEPARATOR << APPVERSION << DIR_SEPARATOR << "pixmaps" << DIR_SEPARATOR << "ghemical.png" << ends;
+
+	pixbuf = gdk_pixbuf_new_from_file(str.str().c_str(), NULL);
+	if(pixbuf == NULL)
+	{
+		printf("Error Loading Icon: %s\n",str.str().c_str()); }
+	else
+	{
+		gtk_window_set_icon(GTK_WINDOW(main_window),pixbuf);
+	}
+	
 	gtk_container_set_border_width(GTK_CONTAINER(main_window), 1);
 	
 	g_signal_connect(G_OBJECT(main_window), "delete_event", G_CALLBACK(gtk_app::DeleteEventHandler), NULL);
@@ -239,7 +415,7 @@ gtk_app::gtk_app(void)
 	
 	GtkActionGroup * action_group2 = gtk_action_group_new("MouseToolToggleActions");
 	gtk_action_group_add_toggle_actions(action_group2, entries2, G_N_ELEMENTS(entries2), NULL);
-	
+
 	ui_manager = gtk_ui_manager_new();
 	gtk_ui_manager_insert_action_group(ui_manager, action_group1, 0);
 	gtk_ui_manager_insert_action_group(ui_manager, action_group2, 0);
@@ -270,7 +446,10 @@ mtb_mtool_rotate_xy = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/r
 mtb_mtool_rotate_z = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/rz");
 mtb_mtool_measure = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/ms");
 	
-	
+#ifdef ENABLE_SHORTCUTS
+	shortcuts_toolbar = gtk_ui_manager_get_widget(ui_manager, "/ShortcutsTB");
+	gtk_box_pack_start(GTK_BOX(main_vbox), shortcuts_toolbar, FALSE, FALSE, 0);
+#endif  // ENABLE_SHORTCUTS
 	
 	// set a new default project.
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -283,6 +462,10 @@ mtb_mtool_measure = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/ms"
 	gtk_widget_show(main_menubar);
 	gtk_widget_show(main_toolbar);
 	
+#ifdef ENABLE_SHORTCUTS
+	gtk_widget_show(shortcuts_toolbar);
+#endif  // ENABLE_SHORTCUTS
+	
 	gtk_widget_show(main_vbox);
 	gtk_widget_show(main_window);
 }
@@ -349,13 +532,20 @@ void gtk_app::mainmenu_FileClose(gpointer, guint, GtkWidget *)
 
 void gtk_app::mainmenu_HelpHelp(gpointer, guint, GtkWidget *)
 {
-	cout << "help not yet implemented!" << endl;
+	ostringstream str; str << "mozilla ";
+	str << project::appdata_path << DIR_SEPARATOR;
+	str << project::appversion << DIR_SEPARATOR;
+	str << "user-docs/index.html &" << ends;
+	
+	cout << "Trying to show the User's Manual using a following command:" << endl;
+	cout << str.str().c_str() << endl;
+	
+	system(str.str().c_str());
 }
 
 void gtk_app::mainmenu_HelpAbout(gpointer, guint, GtkWidget *)
 {
-	static char about[2048];
-	ostrstream about_str(about, sizeof(about));
+	ostringstream about_str;
 	
 	about_str << "ghemical-" << APPVERSION << " released on " << APPRELEASEDATE << endl;
 	about_str << " " << endl;
@@ -373,8 +563,13 @@ void gtk_app::mainmenu_HelpAbout(gpointer, guint, GtkWidget *)
 	about_str << "\t\t" << "Mike Cruz" << endl;
 	about_str << "\t\t" << "Michael Banck" << endl;
 	about_str << "\t\t" << "Christopher Rowley" << endl;
+	about_str << "\t\t" << "Donald Curtis" << endl;
 	
 	about_str << ends;
+	
+	static char about[2048];
+	strcpy(about, about_str.str().c_str());
+	
 	prj->Message(about);
 }
 
@@ -679,6 +874,87 @@ void gtk_app::maintb_dial_Setup(gpointer, guint, GtkWidget *)
 	new setup_dialog(prj);		// will call delete itself...
 }
 
+#ifdef ENABLE_SHORTCUTS
+#ifdef ENABLE_GAMESS
+void gtk_app::shortcutstb_dial_Gamess(gpointer, guint, GtkWidget *)
+{
+	new gamess_dialog(prj);		// will call delete itself...
+	return;
+}
+#endif  // ENABLE_GAMESS
+
+void gtk_app::shortcutstb_dial_ConstrainBondLength(gpointer, guint, GtkWidget *)
+{
+	new constraint_dialog(prj);
+	return;
+}
+
+void gtk_app::shortcutstb_dial_Geomopt(gpointer, guint, GtkWidget *)
+{
+	setup * su = prj->GetCurrentSetup();
+	static jobinfo_GeomOpt ji;
+	
+	ji.prj = prj;
+	ji.go = geomopt_param(su);
+	ji.go.show_dialog = false;
+	ji.go.enable_nsteps = true;
+	ji.go.enable_grad = true;
+	
+	prj->start_job_GeomOpt(& ji);
+	return;
+}
+
+void gtk_app::shortcutstb_action_AddH(gpointer, guint, GtkWidget *)
+{
+	prj->AddH();
+	prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_RemoveH(gpointer, guint, GtkWidget *)
+{
+	prj->RemoveH();
+	prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_SelectAll(gpointer, guint, GtkWidget *)
+{
+	prj->SelectAll();
+	// prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_InvertSelection(gpointer, guint, GtkWidget *)
+{
+	prj->InvertSelection();
+	// prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_SelectNone(gpointer, guint, GtkWidget *)
+{
+	prj->SelectAll();
+	prj->InvertSelection();
+	// prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_LockSelected(gpointer, guint, GtkWidget *)
+{
+	prj->LockSelected();
+	// prj->UpdateAllGraphicsViews();
+	return;
+}
+
+void gtk_app::shortcutstb_action_UnlockSelected(gpointer, guint, GtkWidget *)
+{
+	prj->UnlockSelected();
+	// prj->UpdateAllGraphicsViews();
+	return;
+}
+#endif  // ENABLE_SHORTCUTS
+
 // this part is related to the bonobo server.
 // ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
@@ -739,7 +1015,11 @@ int main(int argc, char ** argv)
 #ifdef ENABLE_BONOBO
 
 		BONOBO_FACTORY_INIT("ghemical", "0.1", & argc, argv);
-		gtk_gl_init(& argc, & argv);
+		
+		gtk_init(& argc, & argv);
+		gdk_gl_init(& argc, & argv);
+		
+		glutInit(& argc, argv);
 		
 		return bonobo_generic_factory_main ("OAFIID:GNOME_Ghemical_ControlFactory", control_factory, NULL);
 		
@@ -767,6 +1047,8 @@ int main(int argc, char ** argv)
 		gtk_init(& argc, & argv);
 		gdk_gl_init(& argc, & argv);
 		
+		glutInit(& argc, argv);
+		
 		singleton_cleaner<gtk_app> app_cleaner;
 		app_cleaner.SetInstance(gtk_app::GetInstance());
 		
@@ -777,9 +1059,7 @@ int main(int argc, char ** argv)
 			ReadGPR(* gtk_app::GetPrj(), ifile, false);
 			ifile.close();
 			
-			//char buffer[256];
-			//prj->ParseProjectFileNameAndPath(filename);
-			//prj->GetProjectFileName(buffer, 256, true);
+			gtk_app::GetPrj()->ParseProjectFileNameAndPath(opt_f);
 		}
 		else if (opt_i != NULL)
 		{
@@ -787,13 +1067,12 @@ int main(int argc, char ** argv)
 #ifdef ENABLE_OPENBABEL
 			
 			gtk_app::GetPrj()->ImportFile(opt_i, 0);
-			
-			//gtk_app::GetPrj()->ParseProjectFileNameAndPath(filename);
+			gtk_app::GetPrj()->ParseProjectFileNameAndPath(opt_i);
 			
 #else	// ENABLE_OPENBABEL
 			
-			cout << "sorry! file import feature is disabled ; you need to recompile" << endl;
-			cout << "libghemical with --enable-openbabel option in order to fix this." << endl;
+			cout << "Sorry! File import feature is disabled ; you need to recompile" << endl;
+			cout << "with --enable-openbabel option in order to fix this." << endl;
 			exit(EXIT_FAILURE);
 			
 #endif	// ENABLE_OPENBABEL
