@@ -22,6 +22,10 @@
 
 #include <unistd.h>
 
+// uncomment this if you wish to have the traditional short toolbar labels.
+// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+//#define USE_SHORT_TOOLBAR_LABELS
+
 /*################################################################################################*/
 
 // this part is related to the GTK+ application.
@@ -48,6 +52,10 @@ class gtk_app
 	static GtkWidget * main_menubar;
 	static GtkWidget * main_toolbar;
 	
+#ifdef ENABLE_SHORTCUTS
+	static GtkWidget * shortcuts_toolbar;
+#endif  // ENABLE_SHORTCUTS
+	
 static GtkWidget * mtb_mtool_draw;
 static GtkWidget * mtb_mtool_erase;
 static GtkWidget * mtb_mtool_select;
@@ -113,6 +121,21 @@ static GtkWidget * mtb_mtool_measure;
 	static void maintb_dial_BondType(gpointer, guint, GtkWidget *);
 	static void maintb_dial_Setup(gpointer, guint, GtkWidget *);
 	
+#ifdef ENABLE_SHORTCUTS
+	static void shortcutstb_dial_Geomopt(gpointer, guint, GtkWidget *);
+	static void shortcutstb_dial_ConstrainBondLength(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_AddH(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_RemoveH(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_SelectAll(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_InvertSelection(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_SelectNone(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_LockSelected(gpointer, guint, GtkWidget *);
+	static void shortcutstb_action_UnlockSelected(gpointer, guint, GtkWidget *);
+#ifdef ENABLE_GAMESS
+	static void shortcutstb_dial_Gamess(gpointer, guint, GtkWidget *);
+#endif  // ENABLE_GAMESS
+#endif  // ENABLE_SHORTCUTS
+	
 	static GtkUIManager * GetUIManager(void) { return ui_manager; }
 	static GtkWidget * GetMainWindow(void) { return main_window; }
 };
