@@ -28,7 +28,9 @@ class camera;		// camera.h
 class graphics_view;	// views.h
 
 #include <ghemical/v3d.h>
-#include <ghemical/libdefine.h>
+
+#include <ghemical/typedef.h>
+#include <ghemical/libghemicaldefine.h>
 
 #include <list>
 #include <vector>
@@ -246,6 +248,25 @@ class ol_dynamic_l1 : public object_location
 
 /*################################################################################################*/
 
+/**	This function can be used to modify a 3D-vector object using a 4x4 transformation 
+	matrix. Will first make a [1*4]x[4x4]-type matrix product and after that bring the 
+	result back to 3D.
+	
+	For more complete documentation search for "##homogeneous coordinates"...
+*/
+
+inline void TransformVector(v3d<fGL> & p1, const fGL * p2)
+{
+	int n1; int n2; fGL pv[4]; pv[3] = 1.0;
+	for (n1 = 0;n1 < 3;n1++) pv[n1] = p1.data[n1];
+	
+	fGL rv[4] = { 0.0, 0.0, 0.0, 0.0 };
+	for (n1 = 0;n1 < 4;n1++) for (n2 = 0;n2 < 4;n2++) rv[n1] += pv[n2] * p2[n2 * 4 + n1];
+	for (n1 = 0;n1 < 3;n1++) p1.data[n1] = rv[n1] / rv[3];
+}
+
+/*################################################################################################*/
+
 #endif	// OBJECTS_H
 
 // eof
