@@ -15,7 +15,7 @@
 #include <GL/gl.h>
 
 #include <fstream>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -249,14 +249,13 @@ color_plane_object::color_plane_object(const object_location & p1, cp_param & p2
 	
 	cp = new color_plane(p2);
 	
-	char buffer[1024];
-	ostrstream str(buffer, sizeof(buffer));
+	ostringstream str;
 	str << p3 << "plane" << ends;
 	
 	copy_of_ref = p2.ref;
 	
-	object_name = new char[strlen(buffer) + 1];
-	strcpy(object_name, buffer);
+	object_name = new char[strlen(str.str().c_str()) + 1];
+	strcpy(object_name, str.str().c_str());
 }
 
 color_plane_object::~color_plane_object(void)
@@ -311,14 +310,13 @@ volume_rendering_object::volume_rendering_object(const object_location & p1,
 	thickness = p4;
 	ConnectCamera(p5);
 	
-	char buffer[1024];
-	ostrstream str(buffer, sizeof(buffer));
+	ostringstream str;
 	str << p6 << "VR" << ends;
 	
 	copy_of_ref = p2.ref;
 	
-	object_name = new char[strlen(buffer) + 1];
-	strcpy(object_name, buffer);
+	object_name = new char[strlen(str.str().c_str()) + 1];
+	strcpy(object_name, str.str().c_str());
 	
 	CameraEvent(p5);
 }
