@@ -50,6 +50,10 @@ class transformer;		// camera.h
 
 #include "filetrans.h"
 
+#ifdef ENABLE_GAMESS
+#include "gamess.h"
+#endif  // ENABLE_GAMESS
+
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
@@ -100,6 +104,12 @@ struct jobinfo_RandomSearch
 
 class project : public model
 {
+	public:
+
+#ifdef ENABLE_GAMESS
+	GamessData * gamess_data;
+#endif	// ENABLE_GAMESS
+	
 	private:
 	
 	graphics_class_factory * graphics_factory;
@@ -131,11 +141,6 @@ class project : public model
 // this could be always open?!?!? is it needed??? improve MDI first...
 	project_view * pv;
 	
-	ifstream * trajfile;
-	i32s traj_num_atoms;
-	i32s total_traj_frames;
-	i32s current_traj_frame;
-	
 	atom * mt_a1;	// measure_tool
 	atom * mt_a2;	// measure_tool
 	atom * mt_a3;	// measure_tool
@@ -220,28 +225,14 @@ class project : public model
 	
 #endif	// ENABLE_OPENBABEL
 	
-	// methods related to MD trajectories...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	
-	void OpenTrajectory(const char *);
-	void CloseTrajectory(void);
-	void ReadFrame(void);
-	// WriteFrame???
-	void EvaluateBFact(void);
-	void EvaluateDiffConst(double);
-	
-	i32s GetTotalFrames(void);
-	ifstream * GetTrajectoryFile(void);
-	
-	i32s GetCurrentFrame(void);
-	void SetCurrentFrame(i32s);
-	
 	// add or remove hydrogen atoms...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
 	void AddH(void);
 	void RemoveH(void);
 	
+	void HtoMethyl(void);
+	
 	// some utility functions.
 	// ^^^^^^^^^^^^^^^^^^^^^^^
 
@@ -250,7 +241,12 @@ class project : public model
 	
 	void SelectAll(void);
 	void InvertSelection(void);
-	void DeleteSelection(void);
+	
+	void HideSelected(void);
+	void ShowSelected(void);
+	void LockSelected(void);
+	void UnlockSelected(void);
+	void DeleteSelected(void);
 	
 	iGLu GetDisplayListIDs(iGLu);
 	void DeleteDisplayLists(iGLu, iGLu);
@@ -264,6 +260,14 @@ class project : public model
 	void AddBond(bond &);		// virtual
 	void RemoveBond(iter_bl);	// virtual
 	
+	void AddConstraint(constraint_dst &);	// virtual
+	void RemoveConstraint(iter_CDl);	// virtual
+	
+#ifdef ENABLE_GAMESS
+	void AddEFPGroup(EFPGroup &);
+	void RemoveEFPGroup(iter_efpgl);
+#endif
+	
 	void InvalidateGroups(void);	// virtual
 	void UpdateChains(void);	// virtual
 	
@@ -333,11 +337,12 @@ class project : public model
 	void InitGL(void);
 	
 /**	Contains the OpenGL rendering commands that draw the 3D-view.
-
+	
 	Selection is done in a rather crude way by dumping the atom pointers directly to 
 	the OGL selection buffer and reading them later there... Works fine as long as 
 	both datatypes have the same size (currently it's 32 bits). If we some day need 
 	64-bit pointers and have only 32-bit sel-buffer we have to use two names...
+	THIS IS FIXED ALREADY...
 */
 	void Render(graphics_view *, rmode);
 
