@@ -10,7 +10,7 @@
 #ifndef SPLINE_H
 #define SPLINE_H
 
-#include "appconfig.h"
+//#include "ghemicalconfig2.h"
 
 class spline;
 
