@@ -13,7 +13,7 @@
 #include "appdefine.h"
 
 #include <deque>
-#include <strstream>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -65,8 +65,6 @@ color_surface::~color_surface(void)
 
 void color_surface::Update(void)
 {
-	char mbuff1[256];
-	
 	xdir = data->ydir.vpr(data->zdir);
 	
 	vdata.resize(0);
@@ -119,9 +117,9 @@ void color_surface::Update(void)
 		Interpolate(n1, tmp1, tmp2);
 		range[n1][1] = vdata.size();
 		
-		ostrstream str1(mbuff1, sizeof(mbuff1));
+		ostringstream str1;
 		str1 << tmp2[0] << " points, " << tmp2[1] << " cycles" << endl << ends;
-		prj->PrintToLog(mbuff1);
+		prj->PrintToLog(str1.str().c_str());
 	}
 	
 	if (automatic_cv2)
@@ -316,9 +314,9 @@ void color_surface::Update(void)
 		}
 	}
 	
-	ostrstream str1(mbuff1, sizeof(mbuff1));
+	ostringstream str1;
 	str1 << ldata.size() << " lines, " << tdata.size() << " triangles." << endl << ends;
-	prj->PrintToLog(mbuff1);
+	prj->PrintToLog(str1.str().c_str());
 	
 	// add/update the primitives, if this is a transparent object...
 	// add/update the primitives, if this is a transparent object...
@@ -543,14 +541,13 @@ color_surface_object::color_surface_object(const object_location & p1, cs_param
 		else break;
 	}
 	
-	char buffer[1024];
-	ostrstream str(buffer, sizeof(buffer));
+	ostringstream str;
 	str << p3 << "surface" << ends;
 	
 	copy_of_ref = p2.ref;
 	
-	object_name = new char[strlen(buffer) + 1];
-	strcpy(object_name, buffer);
+	object_name = new char[strlen(str.str().c_str()) + 1];
+	strcpy(object_name, str.str().c_str());
 }
 
 color_surface_object::~color_surface_object(void)
