@@ -26,7 +26,7 @@
 #include <GL/glu.h>
 #include <GL/glut.h>
 
-#include <strstream>
+#include <sstream>
 #include <algorithm>
 using namespace std;
 
@@ -257,7 +257,10 @@ void * convert_cset_to_plotting_udata(project * mdl, i32s cset)
 	
 	// then just store the coordinates...
 	
-	fGL * ptr2 = (fGL *) ((i32u) udata + sizeof(i32s)); i32s counter = 0;
+//	fGL * ptr2 = (fGL *) ((i32u) udata + sizeof(i32s)); i32s counter = 0;
+////////////////////////////////////////////////////////////////////////////////
+	ptr1++;		// increment the pointer...
+	fGL * ptr2 = (fGL *) ptr1; i32s counter = 0;
 	for (iter_al it1 = mdl->GetAtomsBegin();it1 != mdl->GetAtomsEnd();it1++)
 	{
 		const fGL * cdata = (* it1).GetCRD(cset);
@@ -278,7 +281,10 @@ void apply_udata_as_cset(project * prj, void * udata)
 		return;
 	}
 	
-	fGL * ptr2 = (fGL *) ((i32u) udata + sizeof(i32s)); i32s counter = 0;
+//	fGL * ptr2 = (fGL *) ((i32u) udata + sizeof(i32s)); i32s counter = 0;
+////////////////////////////////////////////////////////////////////////////////
+	ptr1++;		// increment the pointer...
+	fGL * ptr2 = (fGL *) ptr1; i32s counter = 0;
 	for (iter_al it1 = prj->GetAtomsBegin();it1 != prj->GetAtomsEnd();it1++)
 	{
 		const i32s cset = 0;	// how to set this?!?!?!
@@ -457,10 +463,9 @@ void plot1d_view::UserEvent(i32s x, i32s)
 	
 	// ok, we have a valid selection...
 	
-	char mbuff1[256];
-	ostrstream str1(mbuff1, sizeof(mbuff1));
+	ostringstream str1;
 	str1 << name1 << " = " << dv[index].c1 << " " << namev << " = " << dv[index].v << endl << ends;
-	mdl->PrintToLog(mbuff1);
+	mdl->PrintToLog(str1.str().c_str());
 	
 	if (plot_userdata1 == PLOT_USERDATA_STRUCTURE)
 	{
@@ -606,10 +611,9 @@ void plot2d_view::ZoomEvent(i32s dy)
 	f64 zzz = maxv - minv;
 	maxv += mouse_tool::dist_sensitivity * zzz * (fGL) dy / (fGL) size[1];
 	
-	char mbuff1[256];
-	ostrstream str1(mbuff1, sizeof(mbuff1));
+	ostringstream str1;
 	str1 << "now scaling the colours to range " << (maxv - minv) << " kJ/mol" << endl << ends;
-	mdl->PrintToLog(mbuff1);
+	mdl->PrintToLog(str1.str().c_str());
 	
 	Update();
 }
@@ -645,10 +649,9 @@ void plot2d_view::UserEvent(i32s x, i32s y)
 	
 	// ok, we have a valid selection...
 	
-	char mbuff1[256];
-	ostrstream str1(mbuff1, sizeof(mbuff1));
+	ostringstream str1;
 	str1 << name1 << " = " << dv[index].c1 << " " << name2 << " = " << dv[index].c2 << " " << namev << " = " << dv[index].v << endl << ends;
-	mdl->PrintToLog(mbuff1);
+	mdl->PrintToLog(str1.str().c_str());
 	
 	if (plot_userdata2 == PLOT_USERDATA_STRUCTURE)
 	{
@@ -875,15 +878,14 @@ glVertex3f(right - 0.3 * width + diagram_triangle_width, energy + one_pixel_heig
 			fGL xpos; fGL ypos;
 			void * font = GLUT_BITMAP_TIMES_ROMAN_10;
 			
-			char txt[256];
-			ostrstream str(txt, sizeof(txt));
+			ostringstream str;
 			str << "i = " << n1 << " e = " << energy << ends;
 			
 			xpos = 10.0;
 			ypos = ((energy - center) / scale + 0.5) * size[1] - 5.0;	// 5.0 comes from font height 10...
 			ypos += (fGL) (n1 - del_first[n1]) * 10.0;			// 10.0 comes from font height 10...
 			
-			WriteGlutString2D(txt, xpos, ypos, font);
+			WriteGlutString2D(str.str().c_str(), xpos, ypos, font);
 		}
 		
 		delete[] del_first;
@@ -1015,9 +1017,9 @@ if (rc > maxrc) maxrc = rc;
 		}
 	}
 	
-	char txtbuff[256]; ostrstream txts(txtbuff, sizeof(txtbuff));
+	ostringstream txts;
 	txts << "the tresholds were set to " << r_treshold << " and " << p_treshold << endl << ends;
-	mdl->PrintToLog(txtbuff);
+	mdl->PrintToLog(txts.str().c_str());
 	
 	ready = true;
 }
@@ -1098,12 +1100,12 @@ void ssc_view::Render(void)
 // render...
 // render...
 
-	if (!mdl->ref_civ)
+	if (!mdl->GetCI())
 	{
 		return;
 	}
 	
-	vector<chn_info> & ci_vector = (* mdl->ref_civ);
+	vector<chn_info> & ci_vector = (* mdl->GetCI());
 // make a COMMON framework for SSC (now at SF)!
 // make a COMMON framework for SSC (now at SF)!
 // make a COMMON framework for SSC (now at SF)!
