@@ -40,6 +40,10 @@ class project;		// project.h
 #include "mtools.h"
 #include "project.h"
 
+#ifdef ENABLE_GAMESS
+#include "gamess.h"
+#endif  // ENABLE_GAMESS
+
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
 // do not include any gtk/etc stuff here ; this is platform-independent, OpenGL only!!!
@@ -123,6 +127,16 @@ class project_view : virtual public view
 	virtual void BondAdded(bond *) = 0;
 	virtual void BondUpdateItem(bond *) = 0;	///< updates the properties of an existing object.
 	virtual void BondRemoved(bond *) = 0;
+	
+	virtual void ConstraintAdded(constraint_dst *) = 0;
+	virtual void ConstraintUpdateItem(constraint_dst *) = 0;	///< updates the properties of an existing object.
+	virtual void ConstraintRemoved(constraint_dst *) = 0;
+
+#ifdef ENABLE_GAMESS
+	virtual void EFPGroupAdded(EFPGroup *) = 0;
+	virtual void EFPGroupUpdateItem(EFPGroup *) = 0;	///< updates the properties of an existing object.
+	virtual void EFPGroupRemoved(EFPGroup *) = 0;
+#endif  // ENABLE_GAMESS
 };
 
 /*################################################################################################*/
